package com.mob.secverifyplugin;

import android.graphics.Color;
import android.graphics.Typeface;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.StateListDrawable;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.View;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.mob.MobSDK;
import com.mob.secverify.CustomUIRegister;
import com.mob.secverify.CustomViewClickListener;
import com.mob.secverify.datatype.BaseEntity;
import com.mob.secverify.datatype.LandUiSettings;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import static android.view.ViewGroup.LayoutParams.WRAP_CONTENT;
import static com.mob.secverifyplugin.CommonUtil.createBitmap;
import static com.mob.secverifyplugin.CommonUtil.dipToPx;
import static com.mob.tools.utils.ResHelper.pxToDip;

public class LandUiSettingsTransfer {
	public static final String TAG = "Transfer";


	public static LandUiSettings transferLandUiSettings(HashMap map) {
		if (map == null || map.isEmpty()) {
			return null;
		}
		LandUiSettings.Builder builder = (LandUiSettings.Builder) parse(map);
		return builder.build();

	}

	private static BaseEntity parse(HashMap options) {
		LandUiSettings.Builder builder = new LandUiSettings.Builder();
		/**导航栏*/
		if (options.containsKey("customNav")) {
			HashMap nav = (HashMap) options.get("customNav");
			setNavBuilder(builder, nav);
			Log.e(TAG, "setNavBuilderDone");
		}
		if (options.containsKey("customAuthPage")) {
			HashMap page = (HashMap) options.get("customAuthPage");
			setPageBuilder(builder, page);
			Log.e(TAG, "setPageBuilderDone");
		}
		if (options.containsKey("customAuthPageLogo")) {
			HashMap logo = (HashMap) options.get("customAuthPageLogo");
			setLogoBuilder(builder, logo);
			Log.e(TAG, "setLogoBuilderDone");
		}
		if (options.containsKey("customPhoneNumber")) {
			HashMap number = (HashMap) options.get("customPhoneNumber");
			setNumberBuilder(builder, number);
			Log.e(TAG, "setNumberBuilderDone");
		}
		if (options.containsKey("customSwitchNumber")) {
			HashMap switchacc = (HashMap) options.get("customSwitchNumber");
			setSwitchAccBuilder(builder, switchacc);
			Log.e(TAG, "setSwitchAccBuilderDone");
		}
		if (options.containsKey("customCheckBox")) {
			HashMap checkbox = (HashMap) options.get("customCheckBox");
			setCheckBoxBuilder(builder, checkbox);
			Log.e(TAG, "setCheckBoxBuilderDone");
		}
		if (options.containsKey("customPrivacy")) {
			HashMap privacy = (HashMap) options.get("customPrivacy");
			setPrivacyBuilder(builder, privacy);
			Log.e(TAG, "setPrivacyBuilderDone");
		}
		if (options.containsKey("customPrivacyContentPage")) {
			HashMap privacyPage = (HashMap) options.get("customPrivacyContentPage");
			setPrivacyPageBuilder(builder, privacyPage);
			Log.e(TAG, "customPrivacyContentPage");
		}
		if (options.containsKey("customLoginBtn")) {
			HashMap loginBtn = (HashMap) options.get("customLoginBtn");
			setLoginBtnBuilder(builder, loginBtn);
			Log.e(TAG, "setLoginBtnBuilderDone");
		}
		if (options.containsKey("customOperatorSlogan")) {
			HashMap slogan = (HashMap) options.get("customOperatorSlogan");
			setSloganBuilder(builder, slogan);
			Log.e(TAG, "setSloganBuilderDone");
		}
		if (options.containsKey("customDialog")) {
			HashMap dialog = (HashMap) options.get("customDialog");
			setDialogBuilder(builder, dialog);
			Log.e(TAG, "setDialogBuilderDone");
		}
		if (options.containsKey("customView")) {
			HashMap customView = (HashMap) options.get("customView");
			setCustomView(customView);
			Log.e(TAG, "setCustomViewDone");
		}

		return builder;
	}

	private static LandUiSettings.Builder setNavBuilder(LandUiSettings.Builder builder, HashMap nav) {
		if (nav == null){
			return builder;
		}
		if (nav.containsKey("navTransparent")) {
			boolean navTransparent = (boolean) nav.get("navTransparent");
			builder.setNavTransparent(navTransparent);
		}
		if (nav.containsKey("navHidden")) {
			boolean navHidden = (boolean) nav.get("navHidden");
			builder.setNavHidden(navHidden);
		}
		if (nav.containsKey("navColor")) {
			String navColor = (String) nav.get("navColor");
			if (!TextUtils.isEmpty(navColor)) {
				builder.setNavColorId(Color.parseColor(navColor));
			}
		}
		if (nav.containsKey("navTextSize")) {
			/**导航栏文字*/
			int navTextSize = (int) nav.get("navTextSize");
			if (navTextSize > 0) {
				builder.setNavTextSize(navTextSize);
			}
		}
		if (nav.containsKey("navTextColor")) {
			String navTextColor = (String) nav.get("navTextColor");
			if (!TextUtils.isEmpty(navTextColor)) {
				builder.setNavTextColorId(Color.parseColor(navTextColor));
			}
		}
		if (nav.containsKey("navText")) {
			String navText = (String) nav.get("navText");
			if (!TextUtils.isEmpty(navText)) {
				builder.setNavTextId(navText);
			}
		}
		/**导航栏图片*/
		int navReturnImgDrawableWidth = 0;
		int navReturnImgDrawableHeight = 0;
		;
		int navReturnImgDrawableOffsetX = -1;
		int navReturnImgDrawableOffsetRightX = -1;
		int navReturnImgDrawableOffsetY = -1;
		if (nav.containsKey("landScapeLayout")) {
			HashMap navImageDrawableLayout = (HashMap) nav.get("landScapeLayout");
			if (navImageDrawableLayout != null) {
				if (navImageDrawableLayout.containsKey("layoutWidth")) {
					navReturnImgDrawableWidth = (int) navImageDrawableLayout.get("layoutWidth");
				}
				if (navImageDrawableLayout.containsKey("layoutHidth")) {
					navReturnImgDrawableHeight = (int) navImageDrawableLayout.get("layoutHidth");
				}
				if (navImageDrawableLayout.containsKey("layoutTop")) {
					navReturnImgDrawableOffsetY = Math.abs((int) navImageDrawableLayout.get("layoutTop"));
				}
				if (navImageDrawableLayout.containsKey("layoutLeft")) {
					navReturnImgDrawableOffsetX = Math.abs((int) navImageDrawableLayout.get("layoutLeft"));
				}
				if (navImageDrawableLayout.containsKey("layoutRight")) {
					navReturnImgDrawableOffsetRightX = Math.abs((int) navImageDrawableLayout.get("layoutRight"));
				}
			}
		}
		if (navReturnImgDrawableWidth > 0) {
			builder.setNavCloseImgWidth(navReturnImgDrawableWidth);
		}
		if (navReturnImgDrawableHeight > 0) {
			builder.setNavCloseImgHeight(navReturnImgDrawableHeight);
		}
		if (navReturnImgDrawableOffsetX > 0) {
			builder.setNavCloseImgOffsetX(navReturnImgDrawableOffsetX);
		}
		if (navReturnImgDrawableOffsetY > 0) {
			builder.setNavCloseImgOffsetY(navReturnImgDrawableOffsetY);
		}
		if (navReturnImgDrawableOffsetRightX > 0){
			builder.setNavCloseImgOffsetRightX(navReturnImgDrawableOffsetRightX);
		}
		if (navReturnImgDrawableWidth <= 0) {
			navReturnImgDrawableWidth = 30;
		}
		if (navReturnImgDrawableHeight <= 0) {
			navReturnImgDrawableHeight = 30;
		}
		if (nav.containsKey("navCloseImgPath")) {
			String navReturnImgDrawablePath = (String) nav.get("navCloseImgPath"); //assets里，转成drawable
			if (!TextUtils.isEmpty(navReturnImgDrawablePath)) {
				try {
					navReturnImgDrawablePath =  "flutter_assets" + File.separator + "assets" + File.separator +  navReturnImgDrawablePath;
					InputStream is = MobSDK.getContext().getAssets().open(navReturnImgDrawablePath);
					Drawable navReturnImageDrawable = createBitmap(is, dipToPx(MobSDK.getContext(), navReturnImgDrawableWidth), dipToPx(MobSDK.getContext(), navReturnImgDrawableHeight));
					builder.setNavCloseImgId(navReturnImageDrawable);
				} catch (IOException e) {
					e.printStackTrace();
				}
			}

		}

		if (nav.containsKey("navCloseImgHidden")) {
			boolean navReturnImgDrawableHidden = (boolean) nav.get("navCloseImgHidden");
			builder.setNavCloseImgHidden(navReturnImgDrawableHidden);
		}
		return builder;
	}

	private static LandUiSettings.Builder setPageBuilder(LandUiSettings.Builder builder, HashMap page) {
		if (page == null) {
			return builder;
		}
		if (page.containsKey("backgroundImg")) {
			String backgroundImgDrawablepath = (String) page.get("backgroundImg"); //assets里，转成drawable
			if (!TextUtils.isEmpty(backgroundImgDrawablepath)) {
				try {
					backgroundImgDrawablepath =  "flutter_assets" + File.separator + "assets" + File.separator + backgroundImgDrawablepath;
					InputStream is = MobSDK.getContext().getAssets().open(backgroundImgDrawablepath);
					//屏幕宽高
					DisplayMetrics displayMetrics = MobSDK.getContext().getResources().getDisplayMetrics();
					int width = displayMetrics.widthPixels;
					int height = displayMetrics.heightPixels;
					Drawable backgroundImgDrawable = createBitmap(is, width, height);
					builder.setBackgroundImgId(backgroundImgDrawable);
				} catch (IOException e) {
					Log.e(TAG, e.getMessage(), e);
				}
			}
		}

		if (page.containsKey("backgroundClickClose")) {
			boolean backgroundClickClose = (boolean) page.get("backgroundClickClose");
			builder.setBackgroundClickClose(backgroundClickClose);
		}

		if (page.containsKey("fullScreen")) {
			boolean fullScreen = (boolean) page.get("fullScreen");
			builder.setFullScreen(fullScreen);
		}

		if (page.containsKey("immersiveTheme")) {
			boolean immersiveTheme = (boolean) page.get("immersiveTheme");
			builder.setImmersiveTheme(immersiveTheme);
		}

		if (page.containsKey("immersiveStatusTextColorBlack")) {
			boolean immersiveStatusTextColorBlack = (boolean) page.get("immersiveStatusTextColorBlack");
			builder.setImmersiveStatusTextColorBlack(immersiveStatusTextColorBlack);
		}

		return builder;
	}

	private static LandUiSettings.Builder setLogoBuilder(LandUiSettings.Builder builder, HashMap logo) {
		if(logo == null){
			return builder;
		}
		int logoWidth = -1;
		int logoHeight = -1;
		int logoOffsetX = -1;
		int logoOffsetY = -1;
		int logoOffsetBottomY = -1;
		int logoOffsetRightX = -1;
		if (logo.containsKey("landScapeLayout")) {
			HashMap logoLayout = (HashMap) logo.get("landScapeLayout");
			if (logoLayout != null) {
				if (logoLayout.containsKey("layoutWidth")) {
					logoWidth = (int) logoLayout.get("layoutWidth");
				}
				if (logoLayout.containsKey("layoutHidth")) {
					logoHeight = (int) logoLayout.get("layoutHidth");
				}
				if (logoLayout.containsKey("layoutLeft")) {
					logoOffsetX = Math.abs((int) logoLayout.get("layoutLeft"));
				}
				if (logoLayout.containsKey("layoutTop")) {
					logoOffsetY = Math.abs((int) logoLayout.get("layoutTop"));
				}
				if (logoLayout.containsKey("layoutBottom")) {
					logoOffsetBottomY = Math.abs((int) logoLayout.get("layoutBottom"));
				}
				if (logoLayout.containsKey("layoutRight")) {
					logoOffsetRightX = Math.abs((int) logoLayout.get("layoutRight"));
				}
			}
		}
		if (logoWidth <= 0) {
			logoWidth = 80;
		}
		if (logoHeight <= 0) {
			logoHeight = 80;
		}
		builder.setLogoWidth(logoWidth)
				.setLogoHeight(logoHeight);
		if (logo.containsKey("logoImg")) {
			String logoImgDrawablePath = (String) logo.get("logoImg"); //assets里，转成drawable
			if (!TextUtils.isEmpty(logoImgDrawablePath)) {
				try {
					logoImgDrawablePath = "flutter_assets" + File.separator + "assets" + File.separator+ logoImgDrawablePath;
					InputStream is = MobSDK.getContext().getAssets().open(logoImgDrawablePath);
					Drawable logoImgDrawable = createBitmap(is, dipToPx(MobSDK.getContext(), logoWidth), dipToPx(MobSDK.getContext(), logoHeight));
					builder.setLogoImgId(logoImgDrawable);
				} catch (IOException e) {
					Log.e(TAG, e.getMessage(), e);
				}
			}
		}
		if (logoOffsetX > 0) {
			builder.setLogoOffsetX(logoOffsetX);
		}
		if (logoOffsetY > 0) {
			builder.setLogoOffsetY(logoOffsetY);
		}
		if (logoOffsetRightX > 0) {
			builder.setLogoOffsetRightX(logoOffsetRightX);
		}
		if (logoOffsetBottomY > 0) {
			builder.setLogoOffsetBottomY(logoOffsetBottomY);
		}

		if (logo.containsKey("logoHidden")) {
			boolean logoHidden = (boolean) logo.get("logoHidden");
			builder.setLogoHidden(logoHidden);
		}
		if (logo.containsKey("logoAlignParentRight")) {
			boolean logoAlignRight = (boolean) logo.get("logoAlignParentRight");
			builder.setLogoAlignParentRight(logoAlignRight);
		}

		return builder;
	}

	private static LandUiSettings.Builder setNumberBuilder(LandUiSettings.Builder builder, HashMap number) {
		if (number == null) {
			return builder;
		}


		if (number.containsKey("numberColor")) {
			String phoneColor = (String) number.get("numberColor");
			if (!TextUtils.isEmpty(phoneColor)) {
				builder = builder.setNumberColorId(Color.parseColor(phoneColor));
			}
		}
		if (number.containsKey("numberSize")) {
			int phoneSize = (int) number.get("numberSize");
			if (phoneSize > 0) {
				builder = builder.setNumberSizeId(phoneSize);
			}
		}
		if (number.containsKey("numberHidden")) {
			boolean phoneHidden = (boolean) number.get("numberHidden");
			builder = builder.setNumberHidden(phoneHidden);
		}
		int phoneOffsetX = -1;
		int phoneOffsetY = -1;
		int phoneOffsetBottomY = -1;
		int phoneOffsetRightX = -1;
		if (number.containsKey("landScapeLayout")) {
			HashMap numberLayout = (HashMap) number.get("landScapeLayout");
			if (numberLayout != null) {
				if (numberLayout.containsKey("layoutLeft")) {
					phoneOffsetX = Math.abs((int) numberLayout.get("layoutLeft"));
				}
				if (numberLayout.containsKey("layoutTop")) {
					phoneOffsetY = Math.abs((int) numberLayout.get("layoutTop"));
				}
				if (numberLayout.containsKey("layoutBottom")) {
					phoneOffsetBottomY = Math.abs((int) numberLayout.get("layoutBottom"));
				}
				if (numberLayout.containsKey("layoutRight")) {
					phoneOffsetRightX = Math.abs((int) numberLayout.get("layoutRight"));
				}
			}
		}
		if (phoneOffsetX > 0) {
			builder = builder.setNumberOffsetX(phoneOffsetX);
		}
		if (phoneOffsetY > 0) {
			builder = builder.setNumberOffsetY(phoneOffsetY);
		}
		if (phoneOffsetRightX > 0) {
			builder = builder.setNumberOffsetRightX(phoneOffsetRightX);
		}
		if (phoneOffsetBottomY > 0) {
			builder = builder.setNumberOffsetBottomY(phoneOffsetBottomY);
		}

		if (number.containsKey("numberAlignParentRight")) {
			boolean phoneAlignParentRightNumber = (boolean) number.get("numberAlignParentRight");
			builder = builder.setNumberAlignParentRight(phoneAlignParentRightNumber);
		}
		if (number.containsKey("numberBold")) {
			boolean numberBold = (boolean) number.get("numberBold");
			builder = builder.setNumberBold(numberBold);
		}
		return builder;
	}

	private static LandUiSettings.Builder setSwitchAccBuilder(LandUiSettings.Builder builder, HashMap switchacc) {
		if (switchacc == null) {
			return builder;
		}
		/**切换登录*/
		if (switchacc.containsKey("switchAccColor")) {
			String switchAccColor = (String) switchacc.get("switchAccColor");
			if (!TextUtils.isEmpty(switchAccColor)) {
				builder.setSwitchAccColorId(Color.parseColor(switchAccColor));
			}
		}
		if (switchacc.containsKey("switchAccHidden")) {
			boolean switchAccHidden = (boolean) switchacc.get("switchAccHidden");
			builder.setSwitchAccHidden(switchAccHidden);
		}
		if (switchacc.containsKey("switchAccTextSize")) {
			int switchAccTextSize = (int) switchacc.get("switchAccTextSize");
			if (switchAccTextSize > 0) {
				builder.setSwitchAccTextSize(switchAccTextSize);
			}
		}
		if (switchacc.containsKey("switchAccText")) {
			String switchAccText = (String) switchacc.get("switchAccText");
			if (!TextUtils.isEmpty(switchAccText)) {
				builder.setSwitchAccText(switchAccText);
			}
		}
		int switchAccOffsetX = -1;
		int switchAccOffsetY = -1;
		int switchAccOffsetBottomY = -1;
		int switchAccOffsetRightX = -1;
		if (switchacc.containsKey("landScapeLayout")) {
			HashMap switchAccLayout = (HashMap) switchacc.get("landScapeLayout");
			if (switchAccLayout != null) {
				if (switchAccLayout.containsKey("layoutLeft")) {
					switchAccOffsetX = Math.abs((int) switchAccLayout.get("layoutLeft"));
				}
				if (switchAccLayout.containsKey("layoutTop")) {
					switchAccOffsetY = Math.abs((int) switchAccLayout.get("layoutTop"));
				}
				if (switchAccLayout.containsKey("layoutBottom")) {
					switchAccOffsetBottomY = Math.abs((int) switchAccLayout.get("layoutBottom"));
				}
				if (switchAccLayout.containsKey("layoutRight")) {
					switchAccOffsetRightX = Math.abs((int) switchAccLayout.get("layoutRight"));
				}
			}
		}
		if (switchAccOffsetX > 0) {
			builder.setSwitchAccOffsetX(switchAccOffsetX);
		}
		if (switchAccOffsetY > 0) {
			builder.setSwitchAccOffsetY(switchAccOffsetY);
		}
		if (switchAccOffsetRightX > 0) {
			builder.setSwitchAccOffsetRightX(switchAccOffsetRightX);
		}
		if (switchAccOffsetBottomY > 0) {
			builder.setSwitchAccOffsetBottomY(switchAccOffsetBottomY);
		}

		if (switchacc.containsKey("switchAccAlignParentRight")) {
			boolean switchAccAlignParentRight = (boolean) switchacc.get("switchAccAlignParentRight");
			builder.setSwitchAccAlignParentRight(switchAccAlignParentRight);
		}
		if (switchacc.containsKey("switchAccTextBold")) {
			boolean switchAccTextBold = (boolean) switchacc.get("switchAccTextBold");
			builder.setSwitchAccTextBold(switchAccTextBold);
		}
		return builder;
	}

	private static LandUiSettings.Builder setCheckBoxBuilder(LandUiSettings.Builder builder, HashMap checkbox) {
		if (checkbox == null) {
			return builder;
		}
		int checkboxWidth = -1;
		int checkboxHeight = -1;
		int checkboxOffsetX = -1;
		int checkboxOffsetRightX = -1;
		int checkboxOffsetY = -1;
		int checkboxOffsetBottomY = -1;
		if (checkbox.containsKey("portraitLayout")) {
			HashMap checkboxLayout = (HashMap) checkbox.get("portraitLayout");
			if (checkboxLayout != null) {
				if (checkboxLayout.containsKey("layoutWidth")) {
					checkboxWidth = (int) checkboxLayout.get("layoutWidth");
				}
				if (checkboxLayout.containsKey("layoutHeight")) {
					checkboxHeight = (int) checkboxLayout.get("layoutHeight");
				}
				if (checkboxLayout.containsKey("layoutTop")) {
					checkboxOffsetY = Math.abs((int) checkboxLayout.get("layoutTop"));
				}
				if (checkboxLayout.containsKey("layoutLeft")) {
					checkboxOffsetX = Math.abs((int) checkboxLayout.get("layoutLeft"));
				}
				if (checkboxLayout.containsKey("layoutBottom")) {
					checkboxOffsetBottomY = Math.abs((int) checkboxLayout.get("layoutBottom"));
				}
				if (checkboxLayout.containsKey("layoutRight")) {
					checkboxOffsetRightX = Math.abs((int) checkboxLayout.get("layoutRight"));
				}
			}
		}
		if (checkboxWidth <= 0) {
			checkboxWidth = 30;
		}
		if (checkboxHeight <= 0) {
			checkboxHeight = 30;
		}
		if (checkboxOffsetX > 0) {
			builder.setCheckboxOffsetX(checkboxOffsetX);
		}
		if (checkboxOffsetY > 0) {
			builder.setCheckboxOffsetY(checkboxOffsetY);
		}
		if (checkboxOffsetBottomY > 0) {
			builder.setCheckboxOffsetBottomY(checkboxOffsetBottomY);
		}
		if (checkboxOffsetRightX > 0){
			builder.setCheckboxOffsetRightX(checkboxOffsetRightX);
		}

		if (checkbox.containsKey("checkedImg") && checkbox.containsKey("uncheckedImg")) {
			String checkboxCheckedImgPath = (String) checkbox.get("checkedImg"); //assets里，转成drawable
			String checkboxUncheckedImgPath = (String) checkbox.get("uncheckedImg"); //assets里，转成drawable
			if (!TextUtils.isEmpty(checkboxCheckedImgPath) && !TextUtils.isEmpty(checkboxUncheckedImgPath)) {
				try {
					StateListDrawable drawable = new StateListDrawable();

					checkboxUncheckedImgPath = "flutter_assets" + File.separator + "assets" + File.separator+ checkboxUncheckedImgPath;
					InputStream is = MobSDK.getContext().getAssets().open(checkboxUncheckedImgPath);
					Drawable checkboxUncheckedImg = createBitmap(is, dipToPx(MobSDK.getContext(), checkboxWidth), dipToPx(MobSDK.getContext(), checkboxHeight));
					drawable.addState(new int[]{-android.R.attr.state_checked}, checkboxUncheckedImg);

					checkboxCheckedImgPath = "flutter_assets" + File.separator + "assets" + File.separator+ checkboxCheckedImgPath;
					InputStream is1 = MobSDK.getContext().getAssets().open(checkboxCheckedImgPath);
					Drawable checkboxCheckedImg = createBitmap(is1, dipToPx(MobSDK.getContext(), checkboxWidth), dipToPx(MobSDK.getContext(), checkboxHeight));
					drawable.addState(new int[]{android.R.attr.state_checked}, checkboxCheckedImg);
					builder.setCheckboxImgId(drawable);
				} catch (IOException e) {
					Log.e(TAG, e.getMessage(), e);
				}
			}
		}
		if (checkbox.containsKey("checkboxDefaultState")) {
			boolean checkboxDefaultState = (boolean) checkbox.get("checkboxDefaultState");
			builder.setCheckboxDefaultState(checkboxDefaultState);
		}
		if (checkbox.containsKey("checkboxHidden")) {
			boolean checkboxHidden = (boolean) checkbox.get("checkboxHidden");
			builder.setCheckboxHidden(checkboxHidden);
		}
		if (checkbox.containsKey("scale")) {
			double scaleDouble = (double) checkbox.get("scale");
			float scaleFloat = (float) scaleDouble;
			builder.setCheckboxScaleX(scaleFloat);
			builder.setCheckboxScaleY(scaleFloat);
		}
		return builder;
	}

	private static LandUiSettings.Builder setPrivacyBuilder(LandUiSettings.Builder builder, HashMap privacy) {
		if (privacy == null) {
			return builder;
		}
		/**隐私协议*/
		if (privacy.containsKey("agreementBaseTextColor")) {
			String privacyBaseTextColor = (String) privacy.get("agreementBaseTextColor");
			if (!TextUtils.isEmpty(privacyBaseTextColor)) {
				builder.setAgreementBaseTextColorId(Color.parseColor(privacyBaseTextColor));
			}
		}
		if (privacy.containsKey("agreementColor")) {
			String privacyColor = (String) privacy.get("agreementColor");
			if (!TextUtils.isEmpty(privacyColor)) {
				builder.setAgreementColorId(Color.parseColor(privacyColor));
				builder.setCusAgreementColor1(Color.parseColor(privacyColor));
				builder.setCusAgreementColor2(Color.parseColor(privacyColor));
				builder.setCusAgreementColor3(Color.parseColor(privacyColor));
			} else {
				builder.setAgreementColorId(Color.parseColor("#00B6B5"));
				builder.setCusAgreementColor1(Color.parseColor("#00B6B5"));
				builder.setCusAgreementColor2(Color.parseColor("#00B6B5"));
				builder.setCusAgreementColor3(Color.parseColor("#00B6B5"));
			}
		}
		if (privacy.containsKey("agreementTextSize")) {
			int privacyTextSize = (int) privacy.get("agreementTextSize");
			if (privacyTextSize > 0) {
				builder.setAgreementTextSize(privacyTextSize);
			}
		}
		if (privacy.containsKey("agreementHidden")) {
			boolean privacyHidden = (boolean) privacy.get("agreementHidden");
			builder.setAgreementHidden(privacyHidden);
		}
		if (privacy.containsKey("cusAgreementFirstArray")) {
			ArrayList privacyFirstTextArr = (ArrayList) privacy.get("cusAgreementFirstArray");
			if (privacyFirstTextArr != null && privacyFirstTextArr.size() == 3) {
				String cusPrivacyNameOne = "";
				String cusPrivacyUrlOne = "";
				String privacyTextAndOne = "";
				cusPrivacyNameOne = (String) privacyFirstTextArr.get(0);
				cusPrivacyUrlOne = (String) privacyFirstTextArr.get(1);
				privacyTextAndOne = (String) privacyFirstTextArr.get(2);
				if (!TextUtils.isEmpty(cusPrivacyNameOne)) {
					builder.setCusAgreementNameId1(cusPrivacyNameOne);
				}
				if (!TextUtils.isEmpty(cusPrivacyUrlOne)) {
					builder.setCusAgreementUrl1(cusPrivacyUrlOne);
				}
				if (!TextUtils.isEmpty(privacyTextAndOne)) {
					builder.setAgreementTextAnd1(privacyTextAndOne);
				}
			}
		}
		if (privacy.containsKey("cusAgreementSecondArray")) {
			ArrayList privacySecondTextArr = (ArrayList) privacy.get("cusAgreementSecondArray");
			if (privacySecondTextArr != null && privacySecondTextArr.size() == 3) {
				String cusPrivacyNameTwo = "";
				String cusPrivacyUrlTwo = "";
				String privacyTextAndTwo = "";
				cusPrivacyNameTwo = (String) privacySecondTextArr.get(0);
				cusPrivacyUrlTwo = (String) privacySecondTextArr.get(1);
				privacyTextAndTwo = (String) privacySecondTextArr.get(2);
				if (!TextUtils.isEmpty(cusPrivacyNameTwo)) {
					builder.setCusAgreementNameId2(cusPrivacyNameTwo);
				}
				if (!TextUtils.isEmpty(cusPrivacyUrlTwo)) {
					builder.setCusAgreementUrl2(cusPrivacyUrlTwo);
				}
				if (!TextUtils.isEmpty(privacyTextAndTwo)) {
					builder.setAgreementTextAnd2(privacyTextAndTwo);
				}
			}
		}
		if (privacy.containsKey("cusAgreementThirdArray")) {
			ArrayList privacyThirdTextArr = (ArrayList) privacy.get("cusAgreementThirdArray");
			if (privacyThirdTextArr != null && privacyThirdTextArr.size() == 3) {
				String cusPrivacyNameThree = "";
				String cusPrivacyUrlThree = "";
				String privacyTextAndThree = "";
				cusPrivacyNameThree = (String) privacyThirdTextArr.get(0);
				cusPrivacyUrlThree = (String) privacyThirdTextArr.get(1);
				privacyTextAndThree = (String) privacyThirdTextArr.get(2);
				if (!TextUtils.isEmpty(cusPrivacyNameThree)) {
					builder.setCusAgreementNameId3(cusPrivacyNameThree);
				}
				if (!TextUtils.isEmpty(cusPrivacyUrlThree)) {
					builder.setCusAgreementUrl3(cusPrivacyUrlThree);
				}
				if (!TextUtils.isEmpty(privacyTextAndThree)) {
					builder.setAgreementTextAnd3(privacyTextAndThree);
				}
			}
		}
		if (privacy.containsKey("agreementTextStart")) {
			String privacyTextStart = (String) privacy.get("agreementTextStart");
			if (!TextUtils.isEmpty(privacyTextStart)) {
				builder.setAgreementTextStart(privacyTextStart);
			}
		}
		if (privacy.containsKey("agreementTextEnd")) {
			String privacyTextEnd = (String) privacy.get("agreementTextEnd");
			if (TextUtils.isEmpty(privacyTextEnd)) {
				privacyTextEnd = "";
			}
			builder.setAgreementTextEnd(privacyTextEnd);
		}
//		if (privacy.containsKey("MobSDKPrivacyProtocolMarkArr")) {
//			JSONArray protocolMark = privacy.getJSONArray("MobSDKPrivacyProtocolMarkArr");
//			if (protocolMark != null && protocolMark.size() == 2) {
//				try {
//					String protocolMarkStart = protocolMark.get(0);
//					String protocolMarkEnd = protocolMark.get(1);
//					String privacyCmccText = protocolMarkStart + "中国移动认证服务条款" + protocolMarkEnd;
//					String privacyCuccText = protocolMarkStart + "中国联通认证服务条款" + protocolMarkEnd;
//					String privacyCtccText = protocolMarkStart + "中国电信认证服务条款" + protocolMarkEnd;
//					builder.setPrivacyCmccText(privacyCmccText)
//							.setPrivacyCuccText(privacyCuccText)
//							.setPrivacyCtccText(privacyCtccText);
//				} catch (JSONException jsonException) {
//					Log.e(TAG, jsonException.getMessage(), jsonException);
//				}
//
//			}
//		}
		int privacyOffsetX = -1;
		int privacyOffsetRightX = -1;
		int privacyOffsetY = -1;
		int privacyOffsetBottomY = -1;
		if (privacy.containsKey("landScapeLayout")) {
			HashMap privacyLayout = (HashMap) privacy.get("landScapeLayout");
			if (privacyLayout != null) {
				if (privacyLayout.containsKey("layoutTop")) {
					privacyOffsetY = Math.abs((int) privacyLayout.get("layoutTop"));
				}
				if (privacyLayout.containsKey("layoutLeft")) {
					privacyOffsetX = Math.abs((int) privacyLayout.get("layoutLeft"));
				}
				if (privacyLayout.containsKey("layoutBottom")) {
					privacyOffsetBottomY = Math.abs((int) privacyLayout.get("layoutBottom"));
				}
				if (privacyLayout.containsKey("layoutRight")) {
					privacyOffsetRightX = Math.abs((int) privacyLayout.get("layoutRight"));
				}
			}
		}
		if (privacyOffsetX > 0) {
			builder.setAgreementOffsetX(privacyOffsetX);
		}
		if (privacyOffsetY > 0) {
			builder.setAgreementOffsetY(privacyOffsetY);
		}
		if (privacyOffsetBottomY > 0) {
			builder.setAgreementOffsetBottomY(privacyOffsetBottomY);
		}
		if (privacyOffsetRightX > 0){
			builder.setAgreementOffsetRightX(privacyOffsetRightX);
		}

		if (privacy.containsKey("agreementUncheckHintText")) {
			String privacyPromptText = (String) privacy.get("agreementUncheckHintText");
			if (!TextUtils.isEmpty(privacyPromptText)) {
				builder.setAgreementUncheckHintText(privacyPromptText);
			}
		}
		if (privacy.containsKey("agreementTextWithUnderLine")) {
			boolean agreementTextWithUnderLine = (boolean) privacy.get("agreementTextWithUnderLine");
			builder.setAgreementTextWithUnderLine(agreementTextWithUnderLine);
		}
		if (privacy.containsKey("agreementTextBold")) {
			boolean agreementTextBold = (boolean) privacy.get("agreementTextBold");
			builder.setAgreementTextBold(agreementTextBold);
		}
		if (privacy.containsKey("agreementAlignParentRight")) {
			boolean agreementAlignParentRight = (boolean) privacy.get("agreementAlignParentRight");
			builder.setAgreementAlignParentRight(agreementAlignParentRight);
		}
		//暂不添加
		boolean privacyGravityLeft = true;
		return builder;
	}

	private static LandUiSettings.Builder setPrivacyPageBuilder(LandUiSettings.Builder builder, HashMap nav) {
		if (nav == null){
			return builder;
		}
		if (nav.containsKey("agreementPageTitle")) {
			String navText = (String) nav.get("agreementPageTitle");
			if (!TextUtils.isEmpty(navText)) {
				builder.setAgreementPageTitle(navText);
			}
		}
		if (nav.containsKey("cusAgreementPageOneTitle")) {
			String cusAgreementPageOneTitle = (String) nav.get("cusAgreementPageOneTitle");
			if (!TextUtils.isEmpty(cusAgreementPageOneTitle)) {
				builder.setCusAgreementPageOneTitle(cusAgreementPageOneTitle);
			}
		}
		if (nav.containsKey("cusAgreementPageTwoTitle")) {
			String cusAgreementPageTwoTitle = (String) nav.get("cusAgreementPageTwoTitle");
			if (!TextUtils.isEmpty(cusAgreementPageTwoTitle)) {
				builder.setCusAgreementPageTwoTitle(cusAgreementPageTwoTitle);
			}
		}
		if (nav.containsKey("cusAgreementPageThreeTitle")) {
			String cusAgreementPageThreeTitle = (String) nav.get("cusAgreementPageThreeTitle");
			if (!TextUtils.isEmpty(cusAgreementPageThreeTitle)) {
				builder.setCusAgreementPageThreeTitle(cusAgreementPageThreeTitle);
			}
		}
		if (nav.containsKey("agreementPageCloseImgHidden")) {
			boolean agreementPageCloseImgHidden = (boolean) nav.get("agreementPageCloseImgHidden");
			builder.setAgreementPageCloseImgHidden(agreementPageCloseImgHidden);
		}
		if (nav.containsKey("agreementPageTitleHidden")) {
			boolean agreementPageTitleHidden = (boolean) nav.get("agreementPageTitleHidden");
			builder.setAgreementPageTitleHidden(agreementPageTitleHidden);
		}
		if (nav.containsKey("agreementPageTitleTextBold")) {
			boolean agreementPageTitleTextBold = (boolean) nav.get("agreementPageTitleTextBold");
			builder.setAgreementPageTitleTextBold(agreementPageTitleTextBold);
		}
		if (nav.containsKey("agreementPageTitleTextColor")) {
			String agreementPageTitleTextColor = (String) nav.get("agreementPageTitleTextColor");
			builder.setAgreementPageTitleTextColor(Color.parseColor(agreementPageTitleTextColor));
		}
		if (nav.containsKey("agreementPageTitleTextSize")) {
			int agreementPageTitleTextSize = (int) nav.get("agreementPageTitleTextSize");
			builder.setAgreementPageTitleTextSize(agreementPageTitleTextSize);
		}

//				"agreementPageCloseImg": "close.png",//隐私协议页面 返回图标名称
//				"agreementPageCloseImgWidth": 50,//隐私协议页面 返回图标宽度
//				"agreementPageCloseImgHeight": 50,//隐私协议页面 返回图标高度
		/**导航栏图片*/
		int navReturnImgDrawableWidth = 0;
		int navReturnImgDrawableHeight = 0;
		;
		if (nav.containsKey("landScapeLayout")) {
			HashMap navImageDrawableLayout = (HashMap) nav.get("landScapeLayout");
			if (navImageDrawableLayout != null) {
				if (navImageDrawableLayout.containsKey("layoutWidth")) {
					navReturnImgDrawableWidth = (int) navImageDrawableLayout.get("layoutWidth");
				}
				if (navImageDrawableLayout.containsKey("layoutHeight")) {
					navReturnImgDrawableHeight = (int) navImageDrawableLayout.get("layoutHeight");
				}
			}
		}
		if (navReturnImgDrawableWidth > 0) {
			builder.setAgreementPageCloseImgWidth(navReturnImgDrawableWidth);
		}
		if (navReturnImgDrawableHeight > 0) {
			builder.setAgreementPageCloseImgHeight(navReturnImgDrawableHeight);
		}
		if (navReturnImgDrawableWidth <= 0) {
			navReturnImgDrawableWidth = 30;
		}
		if (navReturnImgDrawableHeight <= 0) {
			navReturnImgDrawableHeight = 30;
		}
		if (nav.containsKey("agreementPageCloseImg")) {
			String navReturnImgDrawablePath = (String) nav.get("agreementPageCloseImg"); //assets里，转成drawable
			if (!TextUtils.isEmpty(navReturnImgDrawablePath)) {
				try {
					navReturnImgDrawablePath =  "flutter_assets" + File.separator + "assets" + File.separator +  navReturnImgDrawablePath;
					InputStream is = MobSDK.getContext().getAssets().open(navReturnImgDrawablePath);
					Drawable navReturnImageDrawable = createBitmap(is, dipToPx(MobSDK.getContext(), navReturnImgDrawableWidth), dipToPx(MobSDK.getContext(), navReturnImgDrawableHeight));
					builder.setNavCloseImgId(navReturnImageDrawable);
				} catch (IOException e) {
					e.printStackTrace();
				}
			}

		}

		return builder;
	}

	private static LandUiSettings.Builder setLoginBtnBuilder(LandUiSettings.Builder builder, HashMap loginBtn) {
		if (loginBtn == null) {
			return builder;
		}

		int loginBtnWidth = -1;
		int loginBtnHeight = -1;
		int loginBtnOffsetX = -1;
		int loginBtnOffsetY = -1;
		int loginBtnOffsetBottomY = -1;
		int loginBtnOffsetRightX = -1;
		if (loginBtn.containsKey("landScapeLayout")) {
			HashMap loginBtnLayout = (HashMap) loginBtn.get("landScapeLayout");
			if (loginBtnLayout != null) {
				if (loginBtnLayout.containsKey("layoutWidth")) {
					loginBtnWidth = (int) loginBtnLayout.get("layoutWidth");
				}
				if (loginBtnLayout.containsKey("layoutHeight")) {
					loginBtnHeight = (int) loginBtnLayout.get("layoutHeight");
				}
				if (loginBtnLayout.containsKey("layoutTop")) {
					loginBtnOffsetY = Math.abs((int) loginBtnLayout.get("layoutTop"));
				}
				if (loginBtnLayout.containsKey("layoutLeft")) {
					loginBtnOffsetX = Math.abs((int) loginBtnLayout.get("layoutLeft"));
				}
				if (loginBtnLayout.containsKey("layoutBottom")) {
					loginBtnOffsetBottomY = Math.abs((int) loginBtnLayout.get("layoutBottom"));
				}
				if (loginBtnLayout.containsKey("layoutRight")) {
					loginBtnOffsetRightX = Math.abs((int) loginBtnLayout.get("layoutRight"));
				}
			}
		}
		//如果没有设置，那么设置一个默认值用于设置图片生成bitmap的宽度
		if (loginBtnWidth > 0) {
			builder.setLoginBtnWidth(loginBtnWidth);
		} else {
//			全屏宽度-60dp
			DisplayMetrics metrics = MobSDK.getContext().getResources().getDisplayMetrics();
			int screenWidth = metrics.widthPixels;
			loginBtnWidth = pxToDip(MobSDK.getContext(), screenWidth - dipToPx(MobSDK.getContext(), 60));
		}
		////如果没有设置，那么设置一个默认值用于设置图片的高度
		if (loginBtnHeight > 0) {
			builder.setLoginBtnHeight(loginBtnHeight);
		} else {
			loginBtnHeight = 45;
		}

		if (loginBtnOffsetX > 0) {
			builder.setLoginBtnOffsetX(loginBtnOffsetX);
		}
		if (loginBtnOffsetY > 0) {
			builder.setLoginBtnOffsetY(loginBtnOffsetY);
		}
		if (loginBtnOffsetBottomY > 0) {
			builder.setLoginBtnOffsetBottomY(loginBtnOffsetBottomY);
		}
		if (loginBtnOffsetRightX > 0){
			builder.setLoginBtnOffsetRightX(loginBtnOffsetRightX);
		}
		if (loginBtn.containsKey("loginBtnImgArr")) {
			ArrayList loginBtnImgDrawablePathArray = (ArrayList) loginBtn.get("loginBtnImgArr");
			if (loginBtnImgDrawablePathArray != null && loginBtnImgDrawablePathArray.size() == 3) {
				String loginBtnColorOrImageOne = "";
				String loginBtnColorOrImageTwo = "";
				String loginBtnColorOrImageThree = "";
				loginBtnColorOrImageOne = (String) loginBtnImgDrawablePathArray.get(0);
//				loginBtnColorOrImageTwo = (String) loginBtnImgDrawablePathArray.get(1);
				loginBtnColorOrImageThree = (String) loginBtnImgDrawablePathArray.get(1);
				StateListDrawable drawable = new StateListDrawable();
				if (loginBtnColorOrImageOne.startsWith("#")) {
					drawable.addState(new int[]{-android.R.attr.state_pressed}, new ColorDrawable(Color.parseColor(loginBtnColorOrImageOne)));
				} else {
					try {
						loginBtnColorOrImageOne = "flutter_assets" + File.separator + "assets" + File.separator+ loginBtnColorOrImageOne;
						InputStream is = MobSDK.getContext().getAssets().open(loginBtnColorOrImageOne);
						Drawable drawableStateUnPressed = createBitmap(is, dipToPx(MobSDK.getContext(), loginBtnWidth), dipToPx(MobSDK.getContext(), loginBtnHeight));
						drawable.addState(new int[]{-android.R.attr.state_pressed}, drawableStateUnPressed);
					} catch (IOException e) {
						e.printStackTrace();
					}
				}
//			if (loginBtnColorOrImageTwo.startsWith("#")) {
//				drawable.addState(new int[]{-android.R.attr.state_active}, new ColorDrawable(Color.parseColor(loginBtnColorOrImageTwo)));
//			} else {
//				try {
//			loginBtnColorOrImageTwo =  "flutter_assets" + File.separator + "assets" + File.separator + loginBtnColorOrImageTwo;
//					InputStream is = MobSDK.getContext().getAssets().open(loginBtnColorOrImageTwo);
//					Drawable drawableStateDisable = createBitmap(is, dipToPx(MobSDK.getContext(), loginBtnWidth), dipToPx(MobSDK.getContext(), loginBtnHeight));
//					drawable.addState(new int[]{-android.R.attr.state_active}, drawableStateDisable);
//				} catch (IOException e) {
//					e.printStackTrace();
//				}
//			}
				if (loginBtnColorOrImageThree.startsWith("#")) {
					drawable.addState(new int[]{android.R.attr.state_pressed}, new ColorDrawable(Color.parseColor(loginBtnColorOrImageThree)));
				} else {
					try {
						loginBtnColorOrImageThree = "flutter_assets" + File.separator + "assets" + File.separator  + loginBtnColorOrImageThree;
						InputStream is = MobSDK.getContext().getAssets().open(loginBtnColorOrImageThree);
						Drawable drawableStatePressed = createBitmap(is, dipToPx(MobSDK.getContext(), loginBtnWidth), dipToPx(MobSDK.getContext(), loginBtnHeight));
						drawable.addState(new int[]{android.R.attr.state_pressed}, drawableStatePressed);
					} catch (IOException e) {
						e.printStackTrace();
					}
				}
				builder.setLoginBtnImgId(drawable);
			}
		}

		if (loginBtn.containsKey("loginBtnText")) {
			String loginBtnText = (String) loginBtn.get("loginBtnText");
			if (!TextUtils.isEmpty(loginBtnText)) {
				builder.setLoginBtnTextId(loginBtnText);
			}
		}
		if (loginBtn.containsKey("loginBtnTextColor")) {
			String loginBtnTextColor = (String) loginBtn.get("loginBtnTextColor");
			if (!TextUtils.isEmpty(loginBtnTextColor)) {
				builder.setLoginBtnTextColorId(Color.parseColor(loginBtnTextColor));
			}
		}
		if (loginBtn.containsKey("loginBtnTextSize")) {
			int loginBtnTextSize = (int) loginBtn.get("loginBtnTextSize");
			if (loginBtnTextSize > 0) {
				builder.setLoginBtnTextSize(loginBtnTextSize);
			}
		}
		if (loginBtn.containsKey("loginBtnHidden")) {
			boolean loginBtnHidden = (boolean) loginBtn.get("loginBtnHidden");
			builder.setLoginBtnHidden(loginBtnHidden);
		}
		if (loginBtn.containsKey("loginBtnTextBold")) {
			boolean loginBtnTextBold = (boolean) loginBtn.get("loginBtnTextBold");
			builder.setLoginBtnTextBold(loginBtnTextBold);
		}
		if (loginBtn.containsKey("loginBtnAlignParentRight")) {
			boolean loginBtnAlignParentRight = (boolean) loginBtn.get("loginBtnAlignParentRight");
			builder.setLoginBtnAlignParentRight(loginBtnAlignParentRight);
		}
		return builder;
	}

	private static LandUiSettings.Builder setSloganBuilder(LandUiSettings.Builder builder, HashMap slogan) {
		if (slogan == null) {
			return builder;
		}
		if (slogan.containsKey("sloganTextColor")) {
			String sloganTextColor = (String) slogan.get("sloganTextColor");
			if (!TextUtils.isEmpty(sloganTextColor)) {
				builder.setSloganTextColor(Color.parseColor(sloganTextColor));
			}
		}
		if (slogan.containsKey("sloganTextSize")) {
			int sloganTextSize = (int) slogan.get("sloganTextSize");
			if (sloganTextSize > 0) {
				builder.setSloganTextSize(sloganTextSize);
			}
		}
		if (slogan.containsKey("sloganHidden")) {
			boolean sloganHidden = (boolean) slogan.get("sloganHidden");
			builder.setSloganHidden(sloganHidden);
		}
		if (slogan.containsKey("sloganTextBold")) {
			boolean sloganTextBold = (boolean) slogan.get("sloganTextBold");
			builder.setSloganTextBold(sloganTextBold);
		}
		if (slogan.containsKey("sloganAlignParentRight")) {
			boolean sloganAlignParentRightNumber = (boolean) slogan.get("sloganAlignParentRight");
			builder.setSloganAlignParentRight(sloganAlignParentRightNumber);
		}
		int sloganOffsetX = -1;
		int sloganOffsetY = -1;
		int sloganOffsetBottomY = -1;
		int sloganOffsetRightX = -1;
		if (slogan.containsKey("landScapeLayout")) {
			HashMap sloganLayout = (HashMap) slogan.get("landScapeLayout");
			if (sloganLayout != null) {
				if (sloganLayout.containsKey("layoutTop")) {
					sloganOffsetY = Math.abs((int) sloganLayout.get("layoutTop"));
				}
				if (sloganLayout.containsKey("layoutLeft")) {
					sloganOffsetX = Math.abs((int) sloganLayout.get("layoutLeft"));
				}
				if (sloganLayout.containsKey("layoutBottom")) {
					sloganOffsetBottomY = Math.abs((int) sloganLayout.get("layoutBottom"));
				}
				if (sloganLayout.containsKey("layoutRight")) {
					sloganOffsetRightX = Math.abs((int) sloganLayout.get("layoutRight"));
				}
			}
		}
		if (sloganOffsetX > 0) {
			builder.setSloganOffsetX(sloganOffsetX);
		}
		if (sloganOffsetY > 0) {
			builder.setSloganOffsetY(sloganOffsetY);
		}
		if (sloganOffsetBottomY > 0) {
			builder.setSloganOffsetBottomY(sloganOffsetBottomY);
		}
		if (sloganOffsetRightX > 0){
			builder.setSloganOffsetRightX(sloganOffsetRightX);
		}

		return builder;
	}

	private static LandUiSettings.Builder setDialogBuilder(LandUiSettings.Builder builder, HashMap dialog) {
		if (dialog == null) {
			return builder;
		}
		if (dialog.containsKey("dialogTheme")) {
			boolean dialogTheme = (boolean) dialog.get("dialogTheme");
			builder.setDialogTheme(dialogTheme);
		}
		if (dialog.containsKey("dialogAlignBottom")) {
			boolean dialogAlignBottom = (boolean) dialog.get("dialogAlignBottom");
			builder.setDialogAlignBottom(dialogAlignBottom);
		}
		if (dialog.containsKey("dialogBackgroundClickClose")) {
			boolean dialogBackgroundClickReturn = (boolean) dialog.get("dialogBackgroundClickClose");
			builder.setDialogMaskBackgroundClickClose(dialogBackgroundClickReturn);
		}
		int dialogOffsetX = -1;
		int dialogOffsetY = -1;
		int dialogWidth = -1;
		int dialogHeight = -1;
		if (dialog.containsKey("landScapeLayout")) {
			HashMap dialogLayout = (HashMap) dialog.get("landScapeLayout");
			if (dialogLayout != null) {
				if (dialogLayout.containsKey("layoutLeft")) {
					dialogOffsetX = (int) dialogLayout.get("layoutLeft");
				}
				if (dialogLayout.containsKey("layoutTop")) {
					dialogOffsetY = (int) dialogLayout.get("layoutTop");
				}
				if (dialogLayout.containsKey("layoutWidth")) {
					dialogWidth = (int) dialogLayout.get("layoutWidth");
				}
				if (dialogLayout.containsKey("layoutHeight")) {
					dialogHeight = (int) dialogLayout.get("layoutHeight");
				}
			}
		}
		if (dialogWidth > 0) {
			builder.setDialogWidth(dialogWidth);
		} else {
			dialogWidth = 250;
		}
		if (dialogHeight > 0) {
			builder.setDialogHeight(dialogHeight);
		} else {
			dialogHeight = 400;
		}
		if (dialogOffsetX > 0) {
			builder.setDialogOffsetX(dialogOffsetX);
		}
		if (dialogOffsetY > 0) {
			builder.setDialogOffsetY(dialogOffsetY);
		}
		if (dialog.containsKey("dialogBackground")) {
			String dialogBackgroundPath = (String) dialog.get("dialogBackground");
			if (!TextUtils.isEmpty(dialogBackgroundPath)) {
				dialogBackgroundPath =  "flutter_assets" + File.separator + "assets" + File.separator + dialogBackgroundPath;
				try {
					InputStream is = MobSDK.getContext().getAssets().open(dialogBackgroundPath);
					Drawable logoImgDrawable = createBitmap(is, dipToPx(MobSDK.getContext(), dialogWidth), dipToPx(MobSDK.getContext(), dialogHeight));
					builder.setDialogMaskBackground(logoImgDrawable);
				} catch (IOException e) {
					Log.e(TAG, e.getMessage(), e);
				}
			}
		}
		return builder;
	}

	private static void setCustomView(HashMap customView) {

		if (customView == null) {
			return;
		}
		if (!customView.containsKey("customView")) {
			return;
		}
		List<View> views = new ArrayList<>();
		ArrayList MobSDKCustomViews = (ArrayList) customView.get("customView");
		if (MobSDKCustomViews.size() <= 0) {
			return;
		}

		for (int i = 0; i< MobSDKCustomViews.size(); i++) {
			HashMap customedView = (HashMap) MobSDKCustomViews.get(i);
			if (customedView != null) {
				View view = setViewBuilder(customedView);
				if (view != null) {
					views.add(view);
				}
			}
		}

		if (!views.isEmpty()) {
			CustomUIRegister.addCustomizedUi(views, new CustomViewClickListener() {
				@Override
				public void onClick(View view) {
					Log.e(TAG, "CustomViewClick are not avliable");
				}
			});
		}
	}

	private static View setViewBuilder(HashMap customView) {
		TextView textView = null;
		ImageView imageView = null;
		RelativeLayout.LayoutParams params = new RelativeLayout.LayoutParams(
				WRAP_CONTENT, WRAP_CONTENT);
		if (customView.containsKey("viewClass")) {
			String ViewClass = (String) customView.get("viewClass");
			if (!TextUtils.isEmpty(ViewClass)) {
				if ("TextView".equalsIgnoreCase(ViewClass)) {
					Log.e(TAG, "Current is TextView");
					textView = new TextView(MobSDK.getContext());
					if (customView.containsKey("viewText")) {
						String viewText = (String) customView.get("viewText");
						if (!TextUtils.isEmpty(viewText)) {
							textView.setText(viewText);
						}
					}
					if (customView.containsKey("viewTextColor")) {
						String viewTextColor = (String) customView.get("viewTextColor");
						if (!TextUtils.isEmpty(viewTextColor)) {
							textView.setTextColor(Color.parseColor(viewTextColor));
						}
					}
					if (customView.containsKey("viewTextFont")) {
						int viewTextFont = (int) customView.get("viewTextFont");
						if (viewTextFont > 0) {
							textView.setTextSize(viewTextFont);
						}
					}
					if (customView.containsKey("viewTextBold")) {
						boolean viewTextBold = (boolean) customView.get("viewTextBold");
						if (viewTextBold) {
							textView.setTypeface(Typeface.DEFAULT_BOLD);
						}
					}
					if (customView.containsKey("viewAlignParentRight")) {
						boolean viewAlignParentRight = (boolean) customView.get("viewAlignParentRight");
						if (viewAlignParentRight) {
							params.addRule(RelativeLayout.ALIGN_PARENT_RIGHT);
						}
					}
					if (customView.containsKey("viewHorizontalCenter")) {
						boolean viewHorizontalCenter = (boolean) customView.get("viewHorizontalCenter");
						if (viewHorizontalCenter) {
							params.addRule(RelativeLayout.CENTER_HORIZONTAL);
						}
					}
					int viewOffsetX = -1;
					int viewOffsetY = -1;
					int viewOffsetRightX = -1;
					int viewOffsetBottomY = -1;
					if (customView.containsKey("landScapeLayout")) {
						HashMap viewLayout = (HashMap) customView.get("landScapeLayout");
						if (viewLayout != null) {
							if (viewLayout.containsKey("layoutLeft")) {
								viewOffsetX = Math.abs((int) viewLayout.get("layoutLeft"));
							}
							if (viewLayout.containsKey("layoutTop")) {
								viewOffsetY = Math.abs((int) viewLayout.get("layoutTop"));
							}
							if (viewLayout.containsKey("layoutRight")) {
								viewOffsetRightX = Math.abs((int) viewLayout.get("layoutRight"));
							}
							if (viewLayout.containsKey("layoutBottom")) {
								viewOffsetBottomY = Math.abs((int) viewLayout.get("layoutBottom"));
							}
						}
					} else if (customView.containsKey("portraitLayout")) {
						HashMap viewLayout = (HashMap) customView.get("portraitLayout");
						if (viewLayout != null) {
							if (viewLayout.containsKey("layoutLeft")) {
								viewOffsetX = Math.abs((int) viewLayout.get("layoutLeft"));
							}
							if (viewLayout.containsKey("layoutTop")) {
								viewOffsetY = Math.abs((int) viewLayout.get("layoutTop"));
							}
							if (viewLayout.containsKey("layoutRight")) {
								viewOffsetRightX = Math.abs((int) viewLayout.get("layoutRight"));
							}
							if (viewLayout.containsKey("layoutBottom")) {
								viewOffsetBottomY = Math.abs((int) viewLayout.get("layoutBottom"));
							}
						}
					}
					if (viewOffsetX > 0) {
						params.leftMargin = dipToPx(MobSDK.getContext(),viewOffsetX);
					}
					if (viewOffsetY > 0) {
						params.topMargin = dipToPx(MobSDK.getContext(),viewOffsetY);
					}
					if (viewOffsetRightX > 0) {
						params.rightMargin = dipToPx(MobSDK.getContext(),viewOffsetRightX);
					}
					if (viewOffsetBottomY > 0) {
						params.bottomMargin = dipToPx(MobSDK.getContext(),viewOffsetBottomY);
						params.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM);
					}
					textView.setLayoutParams(params);
				} else if ("ImageView".equalsIgnoreCase(ViewClass)) {
					Log.e(TAG, "Current is ImageView");
					imageView = new ImageView(MobSDK.getContext());
					int viewOffsetX = -1;
					int viewOffsetY = -1;
					int viewOffsetRightX = -1;
					int viewOffsetBottomY = -1;
					int viewWidth = -1;
					int viewHeight = -1;
					if (customView.containsKey("landScapeLayout")) {
						HashMap viewLayout = (HashMap) customView.get("landScapeLayout");
						if (viewLayout != null) {
							if (viewLayout.containsKey("layoutLeft")) {
								viewOffsetX = (int) viewLayout.get("layoutLeft");
							}
							if (viewLayout.containsKey("layoutTop")) {
								viewOffsetY = (int) viewLayout.get("layoutTop");
							}
							if (viewLayout.containsKey("layoutRight")) {
								viewOffsetRightX = (int) viewLayout.get("layoutRight");
							}
							if (viewLayout.containsKey("layoutBottom")) {
								viewOffsetBottomY = (int) viewLayout.get("layoutBottom");
							}
							if (viewLayout.containsKey("layoutWidth")) {
								viewWidth = (int) viewLayout.get("layoutWidth");
							}
							if (viewLayout.containsKey("layoutHeight")) {
								viewHeight = (int) viewLayout.get("layoutHeight");
							}
						}
					} else if (customView.containsKey("portraitLayout")) {
						HashMap viewLayout = (HashMap) customView.get("portraitLayout");
						if (viewLayout != null) {
							if (viewLayout.containsKey("layoutLeft")) {
								viewOffsetX = (int) viewLayout.get("layoutLeft");
							}
							if (viewLayout.containsKey("layoutTop")) {
								viewOffsetY = (int) viewLayout.get("layoutTop");
							}
							if (viewLayout.containsKey("layoutRight")) {
								viewOffsetRightX = (int) viewLayout.get("layoutRight");
							}
							if (viewLayout.containsKey("layoutBottom")) {
								viewOffsetBottomY = (int) viewLayout.get("layoutBottom");
							}
							if (viewLayout.containsKey("layoutWidth")) {
								viewWidth = (int) viewLayout.get("layoutWidth");
							}
							if (viewLayout.containsKey("layoutHeight")) {
								viewHeight = (int) viewLayout.get("layoutHeight");
							}
						}
					}
					if (viewOffsetX > 0) {

						params.leftMargin = dipToPx(MobSDK.getContext(), viewOffsetX);
					}
					if (viewOffsetY > 0) {
						params.topMargin = dipToPx(MobSDK.getContext(), viewOffsetY);
					}
					if (viewOffsetRightX > 0) {
						params.rightMargin = dipToPx(MobSDK.getContext(), viewOffsetRightX);
					}
					if (viewOffsetBottomY > 0) {
						params.bottomMargin = dipToPx(MobSDK.getContext(), viewOffsetBottomY);
						params.addRule(RelativeLayout.ALIGN_PARENT_BOTTOM);
					}

					if (viewWidth > 0) {
						params.width = dipToPx(MobSDK.getContext(), viewWidth);
					} else {
						params.width = dipToPx(MobSDK.getContext(), 30);
					}
					if (viewHeight > 0) {
						params.height = dipToPx(MobSDK.getContext(), viewHeight);
					} else {
						params.height = dipToPx(MobSDK.getContext(), 30);
					}
					if (customView.containsKey("viewImg")) {
						String viewImg = (String) customView.get("viewImg");
						if (!TextUtils.isEmpty(viewImg)) {
							viewImg = "flutter_assets" + File.separator + "assets" + File.separator  + viewImg;
							try {
								InputStream is = MobSDK.getContext().getAssets().open(viewImg);
								Drawable viewImgDrawable = createBitmap(is, viewWidth, viewHeight);
								imageView.setImageDrawable(viewImgDrawable);
							} catch (IOException e) {
								Log.e(TAG, e.getMessage(), e);
							}
						}
					}
					if (customView.containsKey("viewAlignParentRight")) {
						boolean viewAlignParentRight = (boolean) customView.get("viewAlignParentRight");
						if (viewAlignParentRight) {
							params.addRule(RelativeLayout.ALIGN_PARENT_RIGHT);
						}
					}
					if (customView.containsKey("viewHorizontalCenter")) {
						boolean viewHorizontalCenter = (boolean) customView.get("viewHorizontalCenter");
						if (viewHorizontalCenter) {
							params.addRule(RelativeLayout.CENTER_HORIZONTAL);
						}
					}
					imageView.setLayoutParams(params);
				}
			}
		}
		if (textView != null) {
			return textView;
		} else return imageView;

	}
}
