package com.mob.secverifyplugin;

import android.os.Handler;
import android.os.Looper;
import android.util.Log;

import com.mob.MobSDK;
import com.mob.secverify.OAuthPageEventCallback;
import com.mob.secverify.OperationCallback;
import com.mob.secverify.SecVerify;
import com.mob.secverify.VerifyCallback;
import com.mob.secverify.datatype.LandUiSettings;
import com.mob.secverify.datatype.UiSettings;
import com.mob.secverify.datatype.VerifyResult;
import com.mob.secverify.exception.VerifyException;
import com.mob.tools.utils.DeviceHelper;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;


public class SecverifyPlugin implements MethodCallHandler {
	private static final String TAG = "SecVerifyPlugin";
	public static final String CHANNEL = "com.mob.secverifyplugin";


	/**
	 * Plugin registration.
	 */
	public static void registerWith(PluginRegistry.Registrar registrar) {
		Log.d(TAG, " registerWith() called");
		final MethodChannel channel = new MethodChannel(registrar.messenger(), CHANNEL);
		channel.setMethodCallHandler(new SecverifyPlugin());
	}

	@Override
	public void onMethodCall(MethodCall call, Result result) {
		switch (call.method) {
			case "preVerify":
				preVerify(call, result);
				break;
			case "verify":
				verify(call, result);
				break;
			case "setPortraitLayout":
				setUiSettings(call, result);
				break;
			case "setLandscapeLayout":
				setLandUiSettings(call, result);
				break;
			case "finshOauthPage":
				finshOauthPage();
				break;
			case "autoFinishOauthPage":
				autoFinishOauthPage(call);
				otherLoginAutoFinishOAuthPage(call, result);
				break;
			case "OtherOAuthPageCallBack":
				otherOAuthPageCallBack(call, result);
				break;
			case "setTimeOut":
				setTimeOut(call, result);
				break;
			case "setDebugMode":
				setDebugMode(call, result);
				break;
			case "getVersion":
				getVersion(result);
				break;
			case "isVerifySupport":
				isVerifySupport(result);
				break;
			case "submitPrivacyGrantResult":
				submitPrivacyGrantResult(call, result);
				break;
		}
	}

	private void submitPrivacyGrantResult(MethodCall call, Result result) {
		if (call.hasArgument("grantResult")) {
			Boolean grantResult = call.argument("grantResult");
			MobSDK.submitPolicyGrantResult(grantResult, null);
		}
	}

	private void isVerifySupport(Result result) {
		Boolean isSupport = SecVerify.isVerifySupport();
		result.success(isSupport);
	}

	private void setUiSettings(MethodCall call, Result result) {
		if (call.hasArgument("uiSettings")) {
			HashMap map = call.argument("uiSettings");
			UiSettings uiSettings = UiSettingsTransfer.transferUiSettings(map);
			SecVerify.setUiSettings(uiSettings);
		}

	}

	private void setLandUiSettings(MethodCall call, Result result) {
		if (call.hasArgument("landUiSettings")) {
			HashMap map = call.argument("landUiSettings");
			LandUiSettings uiSettings = LandUiSettingsTransfer.transferLandUiSettings(map);
			SecVerify.setLandUiSettings(uiSettings);
		}
	}

	private void finshOauthPage() {
		SecVerify.finishOAuthPage();
	}

	private void autoFinishOauthPage(MethodCall call) {
		boolean hasArg = call.hasArgument("autoFinish");
		if (hasArg) {
			Boolean autoFinish = call.argument("autoFinish");
			SecVerify.autoFinishOAuthPage(autoFinish);
		}
	}

	private void otherLoginAutoFinishOAuthPage(MethodCall call, Result result) {
		if (call.hasArgument("autoFinish")) {
			Boolean autoFinish = call.argument("autoFinish");
			SecVerify.otherLoginAutoFinishOAuthPage(autoFinish);
		}
	}

	private void otherOAuthPageCallBack(MethodCall call, final Result result) {
		SecVerify.OtherOAuthPageCallBack(new OAuthPageEventCallback() {
			@Override
			public void initCallback(OAuthPageEventResultCallback cb) {
				cb.pageOpenCallback(new PageOpenedCallback() {
					@Override
					public void handle() {
						Log.i(TAG, System.currentTimeMillis() + " pageOpenCallback");
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "pageOpenCallback");
						onSuccess(result, map);
					}
				});
				cb.loginBtnClickedCallback(new LoginBtnClickedCallback() {
					@Override
					public void handle() {
						Log.i(TAG, System.currentTimeMillis() + " loginBtnClicked");
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "loginBtnClickedCallback");
						onSuccess(result, map);
					}
				});
				cb.agreementPageClosedCallback(new AgreementPageClosedCallback() {
					@Override
					public void handle() {
						Log.i(TAG, System.currentTimeMillis() + " agreementPageClosed");
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "agreementPageClosedCallback");
						onSuccess(result, map);
					}
				});
				cb.agreementPageOpenedCallback(new AgreementClickedCallback() {
					@Override
					public void handle() {
						Log.i(TAG, System.currentTimeMillis() + " agreementPageOpened");
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "agreementPageOpenedCallback");
						onSuccess(result, map);
					}
				});
				cb.cusAgreement1ClickedCallback(new CusAgreement1ClickedCallback() {
					@Override
					public void handle() {
						Log.i(TAG, System.currentTimeMillis() + " cusAgreement1ClickedCallback");
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "cusAgreement1ClickedCallback");
						onSuccess(result, map);
					}
				});
				cb.cusAgreement2ClickedCallback(new CusAgreement2ClickedCallback() {
					@Override
					public void handle() {
						Log.i(TAG, System.currentTimeMillis() + " cusAgreement2ClickedCallback");
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "cusAgreement2ClickedCallback");
						onSuccess(result, map);
					}
				});
				cb.cusAgreement3ClickedCallback(new CusAgreement3ClickedCallback() {
					@Override
					public void handle() {
						Log.i(TAG, System.currentTimeMillis() + " cusAgreement2ClickedCallback");
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "cusAgreement3ClickedCallback");
						onSuccess(result, map);
					}
				});
				cb.checkboxStatusChangedCallback(new CheckboxStatusChangedCallback() {
					@Override
					public void handle(boolean b) {
						Log.i(TAG, System.currentTimeMillis() + " current status is " + b);
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "checkboxStatusChangedCallback");
						map.put("state", b);
						onSuccess(result, map);
					}
				});
				cb.pageCloseCallback(new PageClosedCallback() {
					@Override
					public void handle() {
						Log.i(TAG, System.currentTimeMillis() + " pageCloseCallback");
						Map<String, Object> map = new HashMap<String, Object>();
						map.put("otherCallback", "pageCloseCallback");
						onSuccess(result, map);
					}
				});
			}
		});

	}

	private void setTimeOut(MethodCall call, Result result) {
		if (call.hasArgument("timeout")) {
			int timeout = call.argument("timeout");
			SecVerify.setTimeOut(timeout);
		}
	}

	private void setDebugMode(MethodCall call, Result result) {
		if (call.hasArgument("debugMode")) {
			boolean debugMode = call.argument("debugMode");
			SecVerify.setDebugMode(debugMode);
		}


	}

	private void preVerify(MethodCall call, final Result result) {
		SecVerify.preVerify(new OperationCallback<Void>() {
			@Override
			public void onComplete(Void o) {
				Map<String, Object> map = new HashMap<String, Object>();
				map.put("success", true);
				onSuccess(result, null);
			}

			@Override
			public void onFailure(VerifyException e) {
				onFail(result, e);
			}
		});
	}


	private void verify(MethodCall call, final Result result) {
		SecVerify.verify(new VerifyCallback() {
			@Override
			public void onOtherLogin() {
				Map<String, Object> map = new HashMap<String, Object>();
				map.put("otherLogin", true);
				onSuccess(result, map);
			}

			@Override
			public void onUserCanceled() {
				Map<String, Object> map = new HashMap<String, Object>();
				map.put("userCacel", true);
				onSuccess(result, map);
			}

			@Override
			public void onComplete(VerifyResult verifyResult) {
				Map<String, Object> map = new HashMap<String, Object>();
				map.put("opToken", verifyResult.getOpToken());
				map.put("token", verifyResult.getToken());
				map.put("operator", verifyResult.getOperator());
				map.put("phoneOperator", verifyResult.getOperator());
				map.put("md5", DeviceHelper.getInstance(MobSDK.getContext()).getSignMD5());
				map.put("appkey", MobSDK.getAppkey());
				onSuccess(result, map);
			}

			@Override
			public void onFailure(VerifyException e) {
				onFail(result, e);
			}
		});
	}

	private void getVersion(Result result) {
		String version = SecVerify.getVersion();
		result.success(version);
	}

	private void onSuccess(final Result result, Map<String, Object> ret) {
		final Map<String, Object> map = new HashMap<>();
		map.put("ret", ret);
		new Handler(Looper.getMainLooper()).post(new Runnable() {
			@Override
			public void run() {
				result.success(map);
			}
		});
	}

	private void onFail(final Result result, final VerifyException e) {
		new Handler(Looper.getMainLooper()).post(new Runnable() {
			@Override
			public void run() {
				final Map<String, Object> map = new HashMap<>();
				final Map<String, Object> err = new HashMap<>();
				String message = "";
				String cause = "";
				if (e != null) {
					message = e.getMessage();
					err.put("message", message);
					Throwable throwable = e.getCause();
					if (throwable != null) {
						cause = throwable.toString();
						err.put("cause", cause);
					}
				}
				map.put("err", err);
				result.success(map);
			}
		});
	}

}
