#import "SecverifyPlugin.h"
#import <SecVerify/SecVerify.h>
#import <MOBFoundation/MobSDK.h>
#import <MOBFoundation/MobSDK+Privacy.h>
#import "UIColor+Hex.h"
#import "UIImage+Yjyz.h"

// Portrait layouts key
static NSString *const YJYZLogoLayoutKey            = @"yjyzLogoLayout";
static NSString *const YJYZPhoneLayoutKey           = @"yjyzPhoneLayout";
static NSString *const YJYZSwitchLayoutKey          = @"yjyzSwitchLayout";
static NSString *const YJYZLoginLayoutKey           = @"yjyzLoginLayout";
static NSString *const YJYZCheckPrivacyLayoutKey    = @"yjyzCheckPrivacyLayout";
static NSString *const YJYZPrivacyLayoutKey         = @"yjyzPrivacyLayout";
static NSString *const YJYZSloganLayoutKey          = @"yjyzSloganLayout";
static NSString *const YJYZBgViewLayoutKey          = @"yjyzBgViewLayout";
static NSString *const YJYZLeftControlLayoutKey     = @"yjyzLeftControlLayout";
static NSString *const YJYZRightControlLayoutKey    = @"yjyzRightControlLayout";

// Landscape layouts key
static NSString *const YJYZLogoLandscapeLayoutKey            = @"yjyzLogoLandscapeLayout";
static NSString *const YJYZPhoneLandscapeLayoutKey           = @"yjyzPhoneLandscapeLayout";
static NSString *const YJYZSwitchLandscapeLayoutKey          = @"yjyzSwitchLandscapeLayout";
static NSString *const YJYZLoginLandscapeLayoutKey           = @"yjyzLoginLandscapeLayout";
static NSString *const YJYZCheckPrivacyLandscapeLayoutKey    = @"yjyzCheckPrivacyLandscapeLayout";
static NSString *const YJYZPrivacyLandscapeLayoutKey         = @"yjyzPrivacyLandscapeLayout";
static NSString *const YJYZSloganLandscapeLayoutKey          = @"yjyzSloganLandscapeLayout";
static NSString *const YJYZBgViewLandscapeLayoutKey          = @"yjyzBgViewLandscapeLayout";
static NSString *const YJYZLeftControlLandscapeLayoutKey     = @"yjyzLeftControlLandscapeLayout";
static NSString *const YJYZRightControlLandscapeLayoutKey    = @"yjyzRightControlLandscapeLayout";

// 是否自动关闭授权页
static BOOL SECAutoDismiss = true;


@interface SecverifyPlugin()

@property (nonatomic, strong) NSDictionary *uiSettingsDict;
@property (nonatomic, strong) NSDictionary *landUISettingsDict;

@end


@implementation SecverifyPlugin

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"com.mob.secverifyplugin"
            binaryMessenger:[registrar messenger]];
  SecverifyPlugin* instance = [[SecverifyPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([@"submitPrivacyGrantResult" isEqualToString:call.method]) {
        id args = call.arguments;
        if ([args isKindOfClass:[NSDictionary class]] &&
            [((NSDictionary *)args).allKeys containsObject:@"grantResult"]) {
            BOOL grant = [args[@"grantResult"] boolValue];
            [MobSDK uploadPrivacyPermissionStatus:grant onResult:nil];
        }
    } else if ([@"getPlatformVersion" isEqualToString:call.method]) {
        result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else if ([@"getVersion" isEqualToString:call.method]) {
        NSString *ver = [SecVerify sdkVersion];
        result(ver);
    } else if ([@"setDebugMode" isEqualToString:call.method]) {
        id args = call.arguments;
        if ([args isKindOfClass:[NSDictionary class]] &&
            [((NSDictionary *)args).allKeys containsObject:@"debugMode"]) {
            BOOL isDebug = [args[@"debugMode"] boolValue];
            [SecVerify setDebug:isDebug];
        }
    } else if ([@"setTimeOut" isEqualToString:call.method]) {
        id args = call.arguments;
        if ([args isKindOfClass:[NSDictionary class]] &&
            [((NSDictionary *)args).allKeys containsObject:@"timeout"]) {
            NSTimeInterval timeout = [args[@"timeout"] doubleValue];
            [SecVerify setTimeoutInterval:timeout];
        }
    } else if ([@"autoFinishOauthPage" isEqualToString:call.method]) {
        id args = call.arguments;
        if ([args isKindOfClass:[NSDictionary class]] &&
            [((NSDictionary *)args).allKeys containsObject:@"autoFinish"]) {
            SECAutoDismiss = [args[@"autoFinish"] boolValue];
        }
    } else if ([@"finshOauthPage" isEqualToString:call.method]) {
        [SecVerify finishLoginVc:nil];
    } else if ([@"setPortraitLayout" isEqualToString:call.method]) {
        id args = call.arguments;
        if ([args isKindOfClass:[NSDictionary class]] &&
            [((NSDictionary *)args).allKeys containsObject:@"uiSettings"]) {
            id uiSettings = args[@"uiSettings"];
            if ([uiSettings isKindOfClass:[NSDictionary class]]) {
                self.uiSettingsDict = uiSettings;
            }
        }
    } else if ([@"setLandscapeLayout" isEqualToString:call.method]) {
        id args = call.arguments;
        if ([args isKindOfClass:[NSDictionary class]] &&
            [((NSDictionary *)args).allKeys containsObject:@"landUiSettings"]) {
            id landUISettings = args[@"landUiSettings"];
            if ([landUISettings isKindOfClass:[NSDictionary class]]) {
                self.landUISettingsDict = landUISettings;
            }
        }
    } else if ([@"isVerifySupport" isEqualToString:call.method]) {
        result(@([SecVerify isVerifyEnable]));
    } else if ([@"preVerify" isEqualToString:call.method]) {
        [SecVerify preLogin:^(NSDictionary * _Nullable resultDic, NSError * _Nullable error) {
            NSMutableDictionary *mdict = [NSMutableDictionary dictionary];
            if (!error) {
                mdict[@"ret"] = resultDic;
            } else {
                mdict[@"err"] = @{
                    @"err_code": @(error.code),
                    @"err_desc": error.localizedDescription,
                };
            }
            result(mdict.copy);
        }];
    } else if ([@"verify" isEqualToString:call.method]) {
        SecVerifyCustomModel *model = [[SecVerifyCustomModel alloc] init];
        model.currentViewController = [UIApplication sharedApplication].keyWindow.rootViewController;
        model.manualDismiss = @(!SECAutoDismiss);
        // 自定义样式
        [self _setupModel:model];
        
        [SecVerify loginWithModel:model completion:^(NSDictionary * _Nullable resultDic, NSError * _Nullable error) {
            NSMutableDictionary *mdict = [NSMutableDictionary dictionary];
            if (!error) {
                NSMutableDictionary *tmp = [NSMutableDictionary dictionary];
                if (resultDic[@"token"]) {
                    tmp[@"token"] = resultDic[@"token"];
                }
                if (resultDic[@"operatorType"]) {
                    tmp[@"operator"] = resultDic[@"operatorType"];
                    tmp[@"phoneOperator"] = resultDic[@"operatorType"];
                }
                if (resultDic[@"operatorToken"]) {
                    tmp[@"opToken"] = resultDic[@"operatorToken"];
                }
                if ([MobSDK appKey]) {
                    tmp[@"appkey"] = [MobSDK appKey];
                }
                mdict[@"ret"] = tmp.copy;
            } else {
                mdict[@"err"] = @{
                    @"err_code": @(error.code),
                    @"err_desc": error.localizedDescription,
                };
            }
            result(mdict.copy);
        }];
    } else {
        result(FlutterMethodNotImplemented);
    }
}


#pragma mark - setup model

- (void)_setupModel:(SecVerifyCustomModel *)model {
    
    if ([_uiSettingsDict isKindOfClass:[NSDictionary class]] && _uiSettingsDict.count > 0) {
        // 用于存储控件布局信息
        NSMutableDictionary *customLayoutsDict = [NSMutableDictionary dictionaryWithCapacity:5];
        
        // customAnimation
        id customAnimation = _uiSettingsDict[@"customAnimation"];
        if (customAnimation && [customAnimation isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customAnimationDict = (NSDictionary *)customAnimation;
            
            if ([customAnimationDict.allKeys containsObject:@"secAnimateType"]) {
                model.animateType = @([customAnimationDict[@"secAnimateType"] integerValue]);
            }
            
            if ([customAnimationDict.allKeys containsObject:@"secShowType"]) {
                model.showType = @([customAnimationDict[@"yjyzShowType"] integerValue]);
            }
            
            id bgColorStr = customAnimationDict[@"secAnimateBgColor"];
            if (bgColorStr && [bgColorStr isKindOfClass:[NSString class]]) {
                model.animateBgColor = [UIColor colorWithHexString:bgColorStr];
            }
            
            id leftControlImgStr = customAnimationDict[@"secLeftControlImage"];
            if (leftControlImgStr && [leftControlImgStr isKindOfClass:[NSString class]]) {
                UIImage *leftImg = [UIImage imageNamed:leftControlImgStr];
                if (leftImg) {
                    model.leftControlImage = leftImg;
                }
            }
            
            if ([customAnimationDict.allKeys containsObject:@"secLeftControlHidden"]) {
                model.leftControlHidden = @([customAnimationDict[@"secLeftControlHidden"] boolValue]);
            }
            
            id rightControlImgStr = customAnimationDict[@"secRightControlImage"];
            if (rightControlImgStr && [rightControlImgStr isKindOfClass:[NSString class]]) {
                UIImage *rightImg = [UIImage imageNamed:rightControlImgStr];
                if (rightImg) {
                    model.rightControlImage = rightImg;
                }
            }
            
            if ([customAnimationDict.allKeys containsObject:@"secRightControlHidden"]) {
                model.rightControlHidden = @([customAnimationDict[@"secRightControlHidden"] boolValue]);
            }
            
            if ([customAnimationDict.allKeys containsObject:@"secBgViewHidden"]) {
                model.bgViewHidden = @([customAnimationDict[@"secBgViewHidden"] boolValue]);
            }
            
            if ([customAnimationDict.allKeys containsObject:@"secBgViewCorner"]) {
                model.bgViewCorner = @([customAnimationDict[@"secBgViewCorner"] floatValue]);
            }
            
            id bgViewColorStr = customAnimationDict[@"secBgViewColor"];
            if (bgViewColorStr && [bgViewColorStr isKindOfClass:[NSString class]]) {
                model.bgViewColor = [UIColor colorWithHexString:bgViewColorStr];
            }
            
            id bgViewImgStr = customAnimationDict[@"secBgViewImage"];
            if (bgViewImgStr && [bgViewImgStr isKindOfClass:[NSString class]]) {
                UIImage *bgImg = [UIImage imageNamed:bgViewImgStr];
                if (bgImg) {
                    model.bgViewImage = bgImg;
                }
            }
            
            if ([customAnimationDict.allKeys containsObject:@"secCloseType"]) {
                model.closeType = @([customAnimationDict[@"secCloseType"] boolValue]);
            }
            
        }
        
        // customNav
        id customNav = _uiSettingsDict[@"customNav"];
        if (customNav && [customNav isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customNavDict = (NSDictionary *)customNav;
            
            id navBarTintColorHexStr = customNavDict[@"secNavBarTintColor"];
            if (navBarTintColorHexStr && [navBarTintColorHexStr isKindOfClass:[NSString class]]) {
                model.navBarTintColor = [UIColor colorWithHexString:navBarTintColorHexStr];
            }
            
            id navText = customNavDict[@"secNavText"];
            if (navText && [navText isKindOfClass:[NSString class]]) {
                NSAttributedString *attrStr = [[NSAttributedString alloc] initWithString:navText];
//                model.navText = navText;
                model.navAttributesText = attrStr;
            }
            
            id navReturnImgName = customNavDict[@"secNavReturnImg"];
            if (navReturnImgName && [navReturnImgName isKindOfClass:[NSString class]]) {
                UIImage *navReturnImg = [UIImage imageNamed:navReturnImgName];
                if (navReturnImg) {
                    model.navReturnImg = navReturnImg;
                }
            }
            
            if ([customNavDict.allKeys containsObject:@"secNavBottomLineHidden"]) {
                model.navBottomLineHidden = @([customNavDict[@"secNavBottomLineHidden"] boolValue]);
            }
            
            if ([customNavDict.allKeys containsObject:@"secNavBarHidden"]) {
                model.navBarHidden = @([customNavDict[@"secNavBarHidden"] boolValue]);
            }
            
            if ([customNavDict.allKeys containsObject:@"secNavStatusBarHidden"]) {
                model.navStatusBarHidden = @([customNavDict[@"secNavStatusBarHidden"] boolValue]);
            }
            
            if ([customNavDict.allKeys containsObject:@"secNavTranslucent"]) {
                model.navTranslucent = @([customNavDict[@"secNavTranslucent"] boolValue]);
            }
            
            if ([customNavDict.allKeys containsObject:@"secNavBackBtnHidden"]) {
                model.navBackBtnHidden = @([customNavDict[@"secNavBackBtnHidden"] boolValue]);
            }
            
            if ([customNavDict.allKeys containsObject:@"secNavLeftControlHidden"]) {
                model.navLeftControlHidden = @([customNavDict[@"secNavLeftControlHidden"] boolValue]);
            }
            
            id navTintColorStr = customNavDict[@"secNavTintColor"];
            if (navTintColorStr && [navTintColorStr isKindOfClass:[NSString class]]) {
                model.navTintColor = [UIColor colorWithHexString:navTintColorStr];
            }
            
            if ([customNavDict.allKeys containsObject:@"secNavBackgroundClear"]) {
                model.navBackgroundClear = @([customNavDict[@"secNavBackgroundClear"] boolValue]);
            }
            
        }
        
        // customAuthPage
        id customAuthPage = _uiSettingsDict[@"customAuthPage"];
        if (customAuthPage && [customAuthPage isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customAuthPageDict = (NSDictionary *)customAuthPage;
            
            id bgColorStr = customAuthPageDict[@"secBackgroundColor"];
            if (bgColorStr && [bgColorStr isKindOfClass:[NSString class]]) {
                model.backgroundColor = [UIColor colorWithHexString:bgColorStr];
            }
            
            id bgImgNameStr = customAuthPageDict[@"secBgImg"];
            if (bgImgNameStr && [bgImgNameStr isKindOfClass:[NSString class]]) {
                UIImage *bgImg = [UIImage imageNamed:bgImgNameStr];
                if (bgImg) {
                    model.bgImg = bgImg;
                }
            }
            
            if ([customAuthPageDict.allKeys containsObject:@"secCancelBySingleClick"]) {
                model.cancelBySingleClick = @([customAuthPageDict[@"secCancelBySingleClick"] boolValue]);
            }
            
        }
        
        // customAuthPageLogo
        id customAuthPageLogo = _uiSettingsDict[@"customAuthPageLogo"];
        if (customAuthPageLogo && [customAuthPageLogo isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customAuthPageLogoDict = (NSDictionary *)customAuthPageLogo;
            
            id logoImgNameStr = customAuthPageLogoDict[@"secLogoImg"];
            if (logoImgNameStr && [logoImgNameStr isKindOfClass:[NSString class]]) {
                UIImage *logoImg = [UIImage imageNamed:logoImgNameStr];
                if (logoImg) {
                    model.logoImg = logoImg;
                }
            }
            
            if ([customAuthPageLogoDict.allKeys containsObject:@"secLogoHidden"]) {
                model.logoHidden = @([customAuthPageLogoDict[@"secLogoHidden"] boolValue]);
            }
            
            if ([customAuthPageLogoDict.allKeys containsObject:@"secLogoCornerRadius"]) {
                model.logoCornerRadius = @([customAuthPageLogoDict[@"secLogoCornerRadius"] integerValue]);
            }
            
            SecVerifyLayout *yjyzLayout = [self secPortraitLayoutWithDict:customAuthPageLogoDict];
            if (yjyzLayout) {
                [customLayoutsDict setObject:yjyzLayout forKey:YJYZLogoLayoutKey];
            }
            
        }
        
        // customPhoneNumber
        id customPhoneNumber = _uiSettingsDict[@"customPhoneNumber"];
        if (customPhoneNumber && [customPhoneNumber isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customPhoneNumberDict = (NSDictionary *)customPhoneNumber;
            
            id numberColorStr = customPhoneNumberDict[@"secNumberColor"];
            if (numberColorStr && [numberColorStr isKindOfClass:[NSString class]]) {
                model.numberColor = [UIColor colorWithHexString:numberColorStr];
            }
            
            if ([customPhoneNumberDict.allKeys containsObject:@"secNumberFont"]) {
                model.numberFont = [UIFont systemFontOfSize:[customPhoneNumberDict[@"secNumberFont"] floatValue]];
            }
            
            if ([customPhoneNumberDict.allKeys containsObject:@"secNumberTextAlignment"]) {
                model.numberTextAlignment = @([customPhoneNumberDict[@"secNumberTextAlignment"] integerValue]);
            }
            
            id numberBgColorStr = customPhoneNumberDict[@"secNumberBgColor"];
            if (numberBgColorStr && [numberBgColorStr isKindOfClass:[NSString class]]) {
                model.numberBgColor = [UIColor colorWithHexString:numberBgColorStr];
            }
            
            if ([customPhoneNumberDict.allKeys containsObject:@"secPhoneHidden"]) {
                model.phoneHidden = @([customPhoneNumberDict[@"secPhoneHidden"] boolValue]);
            }
            
            id phoneBorderColorStr = customPhoneNumberDict[@"secPhoneBorderColor"];
            if (phoneBorderColorStr && [phoneBorderColorStr isKindOfClass:[NSString class]]) {
                model.phoneBorderColor = [UIColor colorWithHexString:phoneBorderColorStr];
            }
            
            if ([customPhoneNumberDict.allKeys containsObject:@"secPhoneBorderWidth"]) {
                model.phoneBorderWidth = @([customPhoneNumberDict[@"secPhoneBorderWidth"] floatValue]);
            }
            
            if ([customPhoneNumberDict.allKeys containsObject:@"secPhoneCorner"]) {
                model.phoneCorner = @([customPhoneNumberDict[@"secPhoneCorner"] floatValue]);
            }
            
            SecVerifyLayout *yjyzLayout = [self secPortraitLayoutWithDict:customPhoneNumberDict];
            if (yjyzLayout) {
                [customLayoutsDict setObject:yjyzLayout forKey:YJYZPhoneLayoutKey];
            }
            
        }
        
        // customSwitchNumber
        id customSwitchNumber = _uiSettingsDict[@"customSwitchNumber"];
        if (customSwitchNumber && [customSwitchNumber isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customSwitchNumberDict = (NSDictionary *)customSwitchNumber;
            
            id bgColorStr = customSwitchNumberDict[@"secSwitchBgColor"];
            if (bgColorStr && [bgColorStr isKindOfClass:[NSString class]]) {
                model.switchBgColor = [UIColor colorWithHexString:bgColorStr];
            }
            
            id colorStr = customSwitchNumberDict[@"secSwitchColor"];
            if (colorStr && [colorStr isKindOfClass:[NSString class]]) {
                model.switchColor = [UIColor colorWithHexString:colorStr];
            }
            
            if ([customSwitchNumberDict.allKeys containsObject:@"secSwitchFont"]) {
                model.switchFont = [UIFont systemFontOfSize:[customSwitchNumberDict[@"secSwitchFont"] floatValue]];
            }
            
            if ([customSwitchNumberDict.allKeys containsObject:@"secSwitchTextHorizontalAlignment"]) {
                model.switchTextHorizontalAlignment = @([customSwitchNumberDict[@"secSwitchTextHorizontalAlignment"] integerValue]);
            }
            
            if ([customSwitchNumberDict.allKeys containsObject:@"secSwitchHidden"]) {
                model.switchHidden = @([customSwitchNumberDict[@"secSwitchHidden"] boolValue]);
            }
            
            id switchText = customSwitchNumberDict[@"secSwitchText"];
            if (switchText && [switchText isKindOfClass:[NSString class]]) {
                model.switchText = switchText;
            }
            
            SecVerifyLayout *yjyzLayout = [self secPortraitLayoutWithDict:customSwitchNumberDict];
            if (yjyzLayout) {
                [customLayoutsDict setObject:yjyzLayout forKey:YJYZSwitchLayoutKey];
            }
            
        }
        
        
        // customCheckBox
        id customCheckBox = _uiSettingsDict[@"customCheckBox"];
        if (customCheckBox && [customCheckBox isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customCheckBoxDict = (NSDictionary *)customCheckBox;
            
            id checkedImgStr = customCheckBoxDict[@"secCheckedImg"];
            if (checkedImgStr && [checkedImgStr isKindOfClass:[NSString class]]) {
                UIImage *checkedImg = [UIImage imageNamed:checkedImgStr];
                if (checkedImg) {
                    model.checkedImg = checkedImg;
                }
            }
            
            id unCheckedImgStr = customCheckBoxDict[@"secUncheckedImg"];
            if (unCheckedImgStr && [unCheckedImgStr isKindOfClass:[NSString class]]) {
                UIImage *unCheckedImg = [UIImage imageNamed:unCheckedImgStr];
                if (unCheckedImg) {
                    model.uncheckedImg = unCheckedImg;
                }
            }
            
            if ([customCheckBoxDict.allKeys containsObject:@"secCheckDefaultState"]) {
                model.checkDefaultState = @([customCheckBoxDict[@"secCheckDefaultState"] boolValue]);
            }
            
            if ([customCheckBoxDict.allKeys containsObject:@"secCheckSize"]) {
                CGFloat value = [customCheckBoxDict[@"secCheckSize"] floatValue];
                model.checkSize = [NSValue valueWithCGSize:CGSizeMake(value, value)];
            }
            
            if ([customCheckBoxDict.allKeys containsObject:@"secCheckHidden"]) {
                model.checkHidden = @([customCheckBoxDict[@"secCheckHidden"] boolValue]);
            }
            
            SecVerifyCheckPrivacyLayout *yjyzLayout = [self secCheckPrivacyPortraitLayoutWithDict:customCheckBoxDict];
            if (yjyzLayout) {
                [customLayoutsDict setObject:yjyzLayout forKey:YJYZCheckPrivacyLayoutKey];
            }
            
        }
        
        
        // customPrivacy
        id customPrivacy = _uiSettingsDict[@"customPrivacy"];
        if (customPrivacy && [customPrivacy isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customPrivacyDict = (NSDictionary *)customPrivacy;
            
            id textColorStr = customPrivacyDict[@"secPrivacyTextColor"];
            if (textColorStr && [textColorStr isKindOfClass:[NSString class]]) {
                model.privacyTextColor = [UIColor colorWithHexString:textColorStr];
            }
            
            if ([customPrivacyDict.allKeys containsObject:@"secPrivacyTextFont"]) {
                float value = [customPrivacyDict[@"secPrivacyTextFont"] floatValue];
                if (value > 0) {
                    model.privacyTextFont = [UIFont systemFontOfSize:value];
                }
            }
            
            if ([customPrivacyDict.allKeys containsObject:@"secPrivacyTextAlignment"]) {
                model.privacyTextAlignment = @([customPrivacyDict[@"secPrivacyTextAlignment"] integerValue]);
            }
            
            id agreementColorStr = customPrivacyDict[@"secPrivacyAgreementColor"];
            if (agreementColorStr && [agreementColorStr isKindOfClass:[NSString class]]) {
                model.privacyAgreementColor = [UIColor colorWithHexString:agreementColorStr];
            }
            
            id agreementBgColorStr = customPrivacyDict[@"secPrivacyAgreementBgColor"];
            if (agreementBgColorStr && [agreementBgColorStr isKindOfClass:[NSString class]]) {
                model.privacyAgreementBgColor = [UIColor colorWithHexString:agreementBgColorStr];
            }
            
            id appNameStr = customPrivacyDict[@"secPrivacyAppName"];
            if (appNameStr && [appNameStr isKindOfClass:[NSString class]]) {
                model.privacyAppName = appNameStr;
            }
            
            id protocolMarkArr = customPrivacyDict[@"secPrivacyProtocolMarkArr"];
            if (protocolMarkArr && [protocolMarkArr isKindOfClass:[NSArray class]]) {
                model.privacyProtocolMarkArr = protocolMarkArr;
            }
            
            id firstTextArr = customPrivacyDict[@"secPrivacyFirstTextArr"];
            if (firstTextArr  && [firstTextArr isKindOfClass:[NSArray class]]) {
                model.privacyFirstTextArr = firstTextArr;
            }
            
            id secondTextArr = customPrivacyDict[@"secPrivacySecondTextArr"];
            if (secondTextArr  && [secondTextArr isKindOfClass:[NSArray class]]) {
                model.privacySecondTextArr = secondTextArr;
            }
            
            if ([customPrivacyDict.allKeys containsObject:@"secPrivacyLineSpacing"]) {
                model.privacyLineSpacing = @([customPrivacyDict[@"secPrivacyLineSpacing"] floatValue]);
            }
            
            id defaultText = customPrivacyDict[@"secPrivacyDefaultText"];
            if (defaultText && [defaultText isKindOfClass:[NSString class]]) {
                model.privacyDefaultText = defaultText;
            }
            
            if ([customPrivacyDict.allKeys containsObject:@"secPrivacyUnderlineStyle"]) {
                model.privacyUnderlineStyle = @([customPrivacyDict[@"secPrivacyUnderlineStyle"] integerValue]);
            }
            
            id normalTextFirst = customPrivacyDict[@"secPrivacyNormalTextFirst"];
            if (normalTextFirst && [normalTextFirst isKindOfClass:[NSString class]]) {
                model.privacyNormalTextFirst = normalTextFirst;
            }
            
            id normalTextSecond = customPrivacyDict[@"secPrivacyNormalTextSecond"];
            if (normalTextSecond && [normalTextSecond isKindOfClass:[NSString class]]) {
                model.privacyNormalTextSecond = normalTextSecond;
            }
            
            id normalTextThird = customPrivacyDict[@"secPrivacyNormalTextThird"];
            if (normalTextThird && [normalTextThird isKindOfClass:[NSString class]]) {
                model.privacyNormalTextThird = normalTextThird;
            }
            
            if ([customPrivacyDict.allKeys containsObject:@"secPrivacyHidden"]) {
                model.privacyHidden = @([customPrivacyDict[@"secPrivacyHidden"] boolValue]);
            }
            
            if ([customPrivacyDict.allKeys containsObject:@"isPrivacyOperatorsLast"]) {
                model.isPrivacyOperatorsLast = @([customPrivacyDict[@"isPrivacyOperatorsLast"] boolValue]);
            }
            
            SecVerifyLayout *yjyzLayout = [self secPortraitLayoutWithDict:customPrivacyDict];
            if (yjyzLayout) {
                [customLayoutsDict setObject:yjyzLayout forKey:YJYZPrivacyLayoutKey];
            }
            
        }
        
        // customPrivacyContentPage
        id customPrivacyContentPage = _uiSettingsDict[@"customPrivacyContentPage"];
        if (customPrivacyContentPage && [customPrivacyContentPage isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customPrivacyContentPageDict = (NSDictionary *)customPrivacyContentPage;
            
            id webBackImgStr = customPrivacyContentPageDict[@"secPrivacyWebBackBtnImage"];
            if (webBackImgStr && [webBackImgStr isKindOfClass:[NSString class]]) {
                UIImage *webBkImg = [UIImage imageNamed:webBackImgStr];
                if (webBkImg) {
                    model.privacyWebBackBtnImage = webBkImg;
                }
            }
            
            id webTitle = customPrivacyContentPageDict[@"secPrivacyWebTitle"];
            if (webTitle && [webTitle isKindOfClass:[NSString class]]) {
                model.privacyWebTitle = [[NSAttributedString alloc] initWithString:webTitle];
            }
            
            if ([customPrivacyContentPageDict.allKeys containsObject:@"secPrivacyWebNavBarStyle"]) {
                model.privacyWebNavBarStyle = @([customPrivacyContentPageDict[@"secPrivacyWebNavBarStyle"] integerValue]);
            }
            
        }
        
        // customLoginBtn
        id customLoginBtn = _uiSettingsDict[@"customLoginBtn"];
        if (customLoginBtn && [customLoginBtn isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customLoginBtnDict = (NSDictionary *)customLoginBtn;
            
            id loginText = customLoginBtnDict[@"secLoginBtnText"];
            if (loginText && [loginText isKindOfClass:[NSString class]]) {
                model.loginBtnText = loginText;
            }
            
            id loginTextColorStr = customLoginBtnDict[@"secLoginBtnTextColor"];
            if (loginTextColorStr && [loginTextColorStr isKindOfClass:[NSString class]]) {
                model.loginBtnTextColor = [UIColor colorWithHexString:loginTextColorStr];
            }
            
            id loginBgColorStr = customLoginBtnDict[@"secLoginBtnBgColor"];
            if (loginBgColorStr && [loginBgColorStr isKindOfClass:[NSString class]]) {
                model.loginBtnBgColor = [UIColor colorWithHexString:loginBgColorStr];
            }
            
            if ([customLoginBtnDict.allKeys containsObject:@"secLoginBtnBorderWidth"]) {
                model.loginBtnBorderWidth = @([customLoginBtnDict[@"secLoginBtnBorderWidth"] floatValue]);
            }
            
            id borderColorStr = customLoginBtnDict[@"secLoginBtnBorderColor"];
            if (borderColorStr && [borderColorStr isKindOfClass:[NSString class]]) {
                model.loginBtnBorderColor = [UIColor colorWithHexString:borderColorStr];
            }
            
            if ([customLoginBtnDict.allKeys containsObject:@"secLoginBtnCornerRadius"]) {
                model.loginBtnCornerRadius = @([customLoginBtnDict[@"secLoginBtnCornerRadius"] floatValue]);
            }
            
            if ([customLoginBtnDict.allKeys containsObject:@"secLoginBtnTextFont"]) {
                float value = [customLoginBtnDict[@"secLoginBtnTextFont"] floatValue];
                if (value > 0) {
                    model.loginBtnTextFont = [UIFont systemFontOfSize:value];
                }
            }
            
            id loginBgImgArr = customLoginBtnDict[@"secLoginBtnBgImgArr"];
            if (loginBgImgArr && [loginBgImgArr isKindOfClass:[NSArray class]]) {
                NSArray *bgImgArr = (NSArray *)loginBgImgArr;
                NSMutableArray *mArr = [NSMutableArray arrayWithCapacity:3];
                for (id imgName in bgImgArr) {
                    if ([imgName isKindOfClass:[NSString class]]) {
                        NSString *imgNameStr = (NSString *)imgName;
                        UIImage *img = nil;
                        if ([imgNameStr hasPrefix:@"#"]) {
                            // 颜色图片
                            UIColor *imgColor = [UIColor colorWithHexString:imgNameStr];
                            img = [UIImage createImageWithColor:imgColor withSize:CGSizeMake(1.0, 1.0)];
                        } else {
                            img = [UIImage imageNamed:imgNameStr];
                        }
                        if (img) {
                            [mArr addObject:img];
                        }
                    }
                }
                
                if (mArr.count > 0) {
                    model.loginBtnBgImgArr = mArr.copy;
                }
            }
            
            if ([customLoginBtnDict.allKeys containsObject:@"secLoginBtnHidden"]) {
                model.loginBtnHidden = @([customLoginBtnDict[@"secLoginBtnHidden"] boolValue]);
            }
            
            SecVerifyLayout *yjyzLayout = [self secPortraitLayoutWithDict:customLoginBtnDict];
            if (yjyzLayout) {
                [customLayoutsDict setObject:yjyzLayout forKey:YJYZLoginLayoutKey];
            }
            
        }
        
        // customOperatorSlogan
        id customOperatorSlogan = _uiSettingsDict[@"customOperatorSlogan"];
        if (customOperatorSlogan && [customOperatorSlogan isKindOfClass:[NSDictionary class]]) {
            NSDictionary *customOperatorSloganDict = (NSDictionary *)customOperatorSlogan;
            
            if ([customOperatorSloganDict.allKeys containsObject:@"secSloganCorner"]) {
                model.sloganCorner = @([customOperatorSloganDict[@"secSloganCorner"] floatValue]);
            }
            
            id borderColorStr = customOperatorSloganDict[@"secSloganBorderColor"];
            if (borderColorStr && [borderColorStr isKindOfClass:[NSString class]]) {
                model.sloganBorderColor = [UIColor colorWithHexString:borderColorStr];
            }
            
            if ([customOperatorSloganDict.allKeys containsObject:@"secSloganBorderWidth"]) {
                model.sloganBorderWidth = @([customOperatorSloganDict[@"secSloganBorderWidth"] floatValue]);
            }
            
            if ([customOperatorSloganDict.allKeys containsObject:@"secSloganTextFont"]) {
                float value = [customOperatorSloganDict[@"secSloganTextFont"] floatValue];
                if (value > 0) {
                    model.sloganTextFont = [UIFont systemFontOfSize:value];
                }
            }
            
            id sloganColorStr = customOperatorSloganDict[@"secSloganTextColor"];
            if (sloganColorStr && [sloganColorStr isKindOfClass:[NSString class]]) {
                model.sloganTextColor = [UIColor colorWithHexString:sloganColorStr];
            }
            
            if ([customOperatorSloganDict.allKeys containsObject:@"secSloganTextAlignment"]) {
                model.sloganTextAlignment = @([customOperatorSloganDict[@"secSloganTextAlignment"] integerValue]);
            }
            
            id sloganBgColorStr = customOperatorSloganDict[@"secSloganBgColor"];
            if (sloganBgColorStr && [sloganBgColorStr isKindOfClass:[NSString class]]) {
                model.sloganBgColor = [UIColor colorWithHexString:sloganBgColorStr];
            }
            
            id sloganText = customOperatorSloganDict[@"secSloganText"];
            if (sloganText && [sloganText isKindOfClass:[NSString class]]) {
                model.sloganText = sloganText;
            }
            
            if ([customOperatorSloganDict.allKeys containsObject:@"secSloganHidden"]) {
                model.sloganHidden = @([customOperatorSloganDict[@"secSloganHidden"] boolValue]);
            }
            
            SecVerifyLayout *yjyzLayout = [self secPortraitLayoutWithDict:customOperatorSloganDict];
            if (yjyzLayout) {
                [customLayoutsDict setObject:yjyzLayout forKey:YJYZSloganLayoutKey];
            }
            
        }
        
        // 设置/更新布局
        [self updateYjyzCustomPortraitLayoutsForModel:model withPortraitLayouts:customLayoutsDict];
        
    }
    else if (_landUISettingsDict.count > 0) {
        // 存在横屏配置
        // 支持横屏
        model.shouldAutorotate = @(YES);
        model.supportedInterfaceOrientations = @(UIInterfaceOrientationMaskAll);
        
    }
    
    
}


#pragma mark - Private

/// 计算竖屏控件布局
/// @param rowDict 包括控件所有属性的字典
- (SecVerifyLayout *)secPortraitLayoutWithDict:(NSDictionary *)rowDict {
    id layout = rowDict[@"secPortraitLayout"];
    if (!layout || ![layout isKindOfClass:[NSDictionary class]]) {
        return nil;
    }
    
    NSDictionary *layoutDict = (NSDictionary *)layout;
    if (layoutDict.count < 1) {
        return nil;
    }
    
    return [self secLayoutWithLayoutDict:layoutDict];
}

/// 计算控件横屏布局
/// @param rowDict 包括控件所有属性的字典
- (SecVerifyLayout *)secLandscapeLayoutWithDict:(NSDictionary *)rowDict {
    id layout = rowDict[@"secLandscapeLayout"];
    if (!layout || ![layout isKindOfClass:[NSDictionary class]]) {
        return nil;
    }
    
    NSDictionary *layoutDict = (NSDictionary *)layout;
    if (layoutDict.count < 1) {
        return nil;
    }
    
    return [self secLayoutWithLayoutDict:layoutDict];
}


/// 计算控件布局
/// @param layoutDict 控件布局属性的字典
- (SecVerifyLayout *)secLayoutWithLayoutDict:(NSDictionary *)layoutDict {
    
    if (layoutDict.count < 1) {
        return nil;
    }
    
    SecVerifyLayout *secLayout = [[SecVerifyLayout alloc] init];
    // 用于标示是否真实存在布局字段
    BOOL isExistLayout = NO;
    
    if ([layoutDict.allKeys containsObject:@"secLayoutTop"]) {
        secLayout.layoutTop = @([layoutDict[@"secLayoutTop"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutBottom"]) {
        secLayout.layoutBottom = @([layoutDict[@"secLayoutBottom"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutLeft"]) {
        secLayout.layoutLeft = @([layoutDict[@"secLayoutLeft"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutRight"]) {
        secLayout.layoutRight = @([layoutDict[@"secLayoutRight"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutWidth"]) {
        secLayout.layoutWidth = @([layoutDict[@"secLayoutWidth"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutHeight"]) {
        secLayout.layoutHeight = @([layoutDict[@"secLayoutHeight"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutCenterX"]) {
        secLayout.layoutCenterX = @([layoutDict[@"secLayoutCenterX"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutCenterY"]) {
        secLayout.layoutCenterY = @([layoutDict[@"secLayoutCenterY"] floatValue]);
        isExistLayout = YES;
    }
    
    return isExistLayout ? secLayout : nil;
}


/// 计算隐私条款勾选框控件竖屏布局
/// @param rowDict 包括控件所有属性的字典
- (SecVerifyCheckPrivacyLayout *)secCheckPrivacyPortraitLayoutWithDict:(NSDictionary *)rowDict {
    id layout = rowDict[@"secPortraitLayout"];
    if (!layout || ![layout isKindOfClass:[NSDictionary class]]) {
        return nil;
    }
    
    NSDictionary *layoutDict = (NSDictionary *)layout;
    if (layoutDict.count < 1) {
        return nil;
    }
    
    return [self secCheckPrivacyLayoutWithLayoutDict:layoutDict];
}

/// 计算隐私条款勾选框控件横屏布局
/// @param rowDict 包括控件所有属性的字典
- (SecVerifyCheckPrivacyLayout *)secCheckPrivacyLandscapeLayoutWithDict:(NSDictionary *)rowDict {
    id layout = rowDict[@"secLandscapeLayout"];
    if (!layout || ![layout isKindOfClass:[NSDictionary class]]) {
        return nil;
    }
    
    NSDictionary *layoutDict = (NSDictionary *)layout;
    if (layoutDict.count < 1) {
        return nil;
    }
    
    return [self secCheckPrivacyLayoutWithLayoutDict:layoutDict];
}

/// 计算隐私条款勾选框控件布局
/// @param layoutDict 包括控件布局属性的字典
- (SecVerifyCheckPrivacyLayout *)secCheckPrivacyLayoutWithLayoutDict:(NSDictionary *)layoutDict {
    if (layoutDict.count < 1) {
        return nil;
    }
    
    SecVerifyCheckPrivacyLayout *yjyzLayout = [[SecVerifyCheckPrivacyLayout alloc] init];
    // 用于标示是否真实存在布局字段
    BOOL isExistLayout = NO;
    
    if ([layoutDict.allKeys containsObject:@"secLayoutTop"]) {
        yjyzLayout.layoutTop = @([layoutDict[@"secLayoutTop"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutRight"]) {
        yjyzLayout.layoutRight = @([layoutDict[@"secLayoutRight"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutWidth"]) {
        yjyzLayout.layoutWidth = @([layoutDict[@"secLayoutWidth"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutHeight"]) {
        yjyzLayout.layoutHeight = @([layoutDict[@"secLayoutHeight"] floatValue]);
        isExistLayout = YES;
    }
    
    if ([layoutDict.allKeys containsObject:@"secLayoutCenterY"]) {
        yjyzLayout.layoutCenterY = @([layoutDict[@"secLayoutCenterY"] floatValue]);
        isExistLayout = YES;
    }
    
    return isExistLayout ? yjyzLayout : nil;
}


/// 更新控件竖屏约束信息
/// @param model UI model
/// @param layoutsDict 竖屏布局对象集合
- (void)updateYjyzCustomPortraitLayoutsForModel:(SecVerifyCustomModel *)model withPortraitLayouts:(NSDictionary *)layoutsDict {
    if (!model || layoutsDict.count < 1) {
        return;
    }
    
    SecVerifyCustomLayouts *layouts = nil;
    if (!model.portraitLayouts) {
        layouts = [[SecVerifyCustomLayouts alloc] init];
    } else {
        layouts = model.portraitLayouts;
    }
    
    id logoLayout = [layoutsDict objectForKey:YJYZLogoLayoutKey];
    if (logoLayout && [logoLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.logoLayout = logoLayout;
    }
    
    id phoneLayout = [layoutsDict objectForKey:YJYZPhoneLayoutKey];
    if (logoLayout && [logoLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.phoneLayout = phoneLayout;
    }
    
    id switchLayout = [layoutsDict objectForKey:YJYZSwitchLayoutKey];
    if (switchLayout && [switchLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.switchLayout = switchLayout;
    }
    
    id checkLayout = [layoutsDict objectForKey:YJYZCheckPrivacyLayoutKey];
    if (checkLayout && [checkLayout isKindOfClass:[SecVerifyCheckPrivacyLayout class]]) {
        layouts.checkPrivacyLayout = checkLayout;
    }
    
    id privacyLayout = [layoutsDict objectForKey:YJYZPrivacyLayoutKey];
    if (privacyLayout && [privacyLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.privacyLayout = privacyLayout;
    }
    
    id loginLayout = [layoutsDict objectForKey:YJYZLoginLayoutKey];
    if (loginLayout && [loginLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.loginLayout = loginLayout;
    }
    
    id sloganLayout = [layoutsDict objectForKey:YJYZSloganLayoutKey];
    if (sloganLayout && [sloganLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.sloganLayout = sloganLayout;
    }
    
    // update
    model.portraitLayouts = layouts;
}


/// 更新控件横屏布局信息
/// @param model UI model
/// @param layoutsDict 横屏布局对象集合
- (void)updateYjyzCustomLandscapeLayoutsForModel:(SecVerifyCustomModel *)model withLandscapeLayouts:(NSDictionary *)layoutsDict {
    if (!model || layoutsDict.count < 1) {
        return;
    }
    
    SecVerifyCustomLayouts *layouts = nil;
    if (!model.landscapeLayouts) {
        layouts = [[SecVerifyCustomLayouts alloc] init];
    } else {
        layouts = model.landscapeLayouts;
    }
    
    id logoLayout = [layoutsDict objectForKey:YJYZLogoLandscapeLayoutKey];
    if (logoLayout && [logoLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.logoLayout = logoLayout;
    }
    
    id phoneLayout = [layoutsDict objectForKey:YJYZPhoneLandscapeLayoutKey];
    if (logoLayout && [logoLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.phoneLayout = phoneLayout;
    }
    
    id switchLayout = [layoutsDict objectForKey:YJYZSwitchLandscapeLayoutKey];
    if (switchLayout && [switchLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.switchLayout = switchLayout;
    }
    
    id checkLayout = [layoutsDict objectForKey:YJYZCheckPrivacyLandscapeLayoutKey];
    if (checkLayout && [checkLayout isKindOfClass:[SecVerifyCheckPrivacyLayout class]]) {
        layouts.checkPrivacyLayout = checkLayout;
    }
    
    id privacyLayout = [layoutsDict objectForKey:YJYZPrivacyLandscapeLayoutKey];
    if (privacyLayout && [privacyLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.privacyLayout = privacyLayout;
    }
    
    id loginLayout = [layoutsDict objectForKey:YJYZLoginLandscapeLayoutKey];
    if (loginLayout && [loginLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.loginLayout = loginLayout;
    }
    
    id sloganLayout = [layoutsDict objectForKey:YJYZSloganLandscapeLayoutKey];
    if (sloganLayout && [sloganLayout isKindOfClass:[SecVerifyLayout class]]) {
        layouts.sloganLayout = sloganLayout;
    }
    
    // update
    model.landscapeLayouts = layouts;
}



// 获取当前显示的 UIViewController
+ (UIViewController *)dc_findCurrentShowingViewController {
    //获得当前活动窗口的根视图
    UIViewController *vc = [UIApplication sharedApplication].keyWindow.rootViewController;
    UIViewController *currentShowingVC = [self findCurrentShowingViewControllerFrom:vc];
    return currentShowingVC;
}


+ (UIViewController *)findCurrentShowingViewControllerFrom:(UIViewController *)vc {
    // 递归方法 Recursive method
    UIViewController *currentShowingVC;
    if ([vc presentedViewController]) {
        // 当前视图是被presented出来的
        UIViewController *nextRootVC = [vc presentedViewController];
        currentShowingVC = [self findCurrentShowingViewControllerFrom:nextRootVC];

    } else if ([vc isKindOfClass:[UITabBarController class]]) {
        // 根视图为UITabBarController
        UIViewController *nextRootVC = [(UITabBarController *)vc selectedViewController];
        currentShowingVC = [self findCurrentShowingViewControllerFrom:nextRootVC];

    } else if ([vc isKindOfClass:[UINavigationController class]]){
        // 根视图为UINavigationController
        UIViewController *nextRootVC = [(UINavigationController *)vc visibleViewController];
        currentShowingVC = [self findCurrentShowingViewControllerFrom:nextRootVC];

    } else {
        // 根视图为非导航类
        currentShowingVC = vc;
    }

    return currentShowingVC;
}



#pragma mark - getter

- (NSDictionary *)uiSettingsDict {
    if (!_uiSettingsDict) {
        _uiSettingsDict = [NSDictionary dictionary];
    }
    return _uiSettingsDict;
}

- (NSDictionary *)landUISettingsDict {
    if (!_landUISettingsDict) {
        _landUISettingsDict = [NSDictionary dictionary];
    }
    return _landUISettingsDict;
}

@end
