import 'dart:async';

import 'package:flutter/services.dart';

class Secverify {
  static const MethodChannel _channel =
      const MethodChannel('com.mob.secverifyplugin');

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future preVerify(Function(Map ret, Map err) result) {
    Future<dynamic> callback = _channel.invokeMethod('preVerify');
    callback.then((dynamic response) {
      if (result != null) {
        if (response is Map) {
          result(response["ret"], response["err"]);
        } else {
          result(null, null);
        }
      }
    });
    return callback;
  }

  static Future verify(Function(Map ret, Map err) result) {
    Future<dynamic> callback = _channel.invokeMethod('verify');
    callback.then((dynamic response) {
      if (result != null) {
        if (response is Map) {
          result(response["ret"], response["err"]);
        } else {
          result(null, null);
        }
      }
    });
    return callback;
  }

  static Future setPortraitLayout(Map params) {
    Map args = {"uiSettings": params};
    _channel.invokeMethod('setPortraitLayout', args);
  }

  static void submitPrivacyGrantResult(bool grantResult) {
    Map args = {"grantResult": grantResult};
    _channel.invokeMethod('submitPrivacyGrantResult', args);
  }

  static Future setLandscapeLayout(Map params) {
    Map args = {"landUiSettings": params};
    _channel.invokeMethod('setLandscapeLayout', args);
  }

  static Future finshOauthPage() {
    _channel.invokeMethod('finshOauthPage');
  }

  static Future autoFinishOauthPage(bool autoFinish) {
    Map args = {"autoFinish": autoFinish};
    _channel.invokeMethod('autoFinishOauthPage', args);
  }

  static Future setTimeOut(int timeout) {
    Map args = {"timeout": timeout};
    _channel.invokeMethod('setTimeOut', args);
  }

  static Future setDebugMode(bool debugMode) {
    Map args = {"debugMode": debugMode};
    _channel.invokeMethod('setDebugMode', args);
  }

  static Future<String> get getVersion async {
    final String version = await _channel.invokeMethod('getVersion');
    return version;
  }

  static Future<bool> get isVerifySupport async {
    final bool isVerifySupport = await _channel.invokeMethod('isVerifySupport');
    return isVerifySupport;
  }
}
